@@ -4,28 +4,32 @@
 #include <QWidget>
 #include <QToolButton>
 #include <QLabel>
+#include <QPushButton>
 
 namespace Ui {
 class Btn_new;
 }
 class Clock;
-class Btn_new : public  QToolButton
+class Btn_new : public  QPushButton
 {
     Q_OBJECT
 
 public:
-    explicit Btn_new(int num, Clock *widget, QIcon icon , QString name , QWidget *parent = nullptr);
+    explicit Btn_new(int num, QString name , QWidget *parent = nullptr);
     ~Btn_new();
+    QLabel *nameLabel;
+    QLabel *textLabel;
+    QLabel *noName;
+    QLabel *IconLabel;
 
+    void paintEvent(QPaintEvent *event);
+    void updateWidthForFontChange(int px);
 private:
     Ui::Btn_new *ui;
-    QLabel *IconLabel;
-    QLabel *textLabel;
     Clock * m_pclock;
     int clock_num;
     int pressflag;
 protected:
-    void mouseReleaseEvent(QMouseEvent *event);//鼠标松开事件
 };
 
 #endif // BTN_NEW_H
