@@ -20,6 +20,9 @@
 
 #include <QWidget>
 #include <QLabel>
+#include <QGSettings>
+#include "constant_class.h"
+
 
 namespace Ui {
 class stopwatch_item;
@@ -34,6 +37,9 @@ public:
     ~stopwatch_item();
     void setupUi(QWidget *stopwatch_item);
     void retranslateUi(QWidget *stopwatch_item);
+    void  settingsStyle();
+    void  blackStyle();                                                                  //黑色主题
+    void  whiteStyle();                                                                  //白色主题
 
     QLabel *stopwatch1;
     QLabel *stopwatch2;
