@@ -17,17 +17,18 @@
 */
 #include "fileitemInit.h"
 #include <QWidget>
+#include "browseButton.h"
 
-fileitem_init::fileitem_init(QWidget *parent) :
+fileItemInit::fileItemInit(QWidget *parent) :
     QWidget(parent)
 {
     if (this->objectName().isEmpty())
-        this->setObjectName(QString::fromUtf8("fileitem_init"));
-    deletebtn0 = new QPushButton(this);
+        this->setObjectName(QString::fromUtf8("fileItemInit"));
+    deletebtn0 = new browseButton(this);
     filename_label0 = new QLabel(this);
     filesize_label0 = new QLabel(this);
 }
 
-fileitem_init::~fileitem_init()
+fileItemInit::~fileItemInit()
 {
 }
