@@ -21,11 +21,10 @@
 #include <QDialog>
 #include <QPushButton>
 #include <QLabel>
-#include "closebtnHover.h"
+#include <QPainter>
 
 class feedback;
 
-
 class submit_success : public QDialog
 {
     Q_OBJECT
@@ -51,7 +50,7 @@ private:
     void UI_init();
 
     QLabel *label;
-    closeBtn_hover * succ_closeBtn;
+    QPushButton * succ_closeBtn;
     QPushButton *pushButton;
     QPushButton *pushButton_2;
     QLabel *label_2;
