@@ -34,6 +34,7 @@ void systeminfo_button::enterEvent(QEvent *e)
 {
     QPointF position = QCursor::pos();
     pfeedback->systeminfo_show(position);
+    pfeedback->setFocus();
 }
 
 void systeminfo_button::leaveEvent(QEvent *e)
@@ -41,7 +42,6 @@ void systeminfo_button::leaveEvent(QEvent *e)
     pfeedback->systeminfo_hide();
 }
 
-//Resource/feedback_en.qm
 void systeminfo_button::setFeedBack(feedback *p)
 {
     pfeedback = p;
