@@ -27,7 +27,7 @@ noteHead::noteHead(QWidget *parent) :
   , ui(new Ui::noteHead)
 {
     ui->setupUi(this);
-    this->resize(250,8);
+    setMinimumSize(250, 8);
 }
 
 noteHead::~noteHead()
@@ -37,19 +37,11 @@ noteHead::~noteHead()
 
 void noteHead::paintEvent(QPaintEvent *event)
 {
-    QPainter painter(this);
-    painter.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
-    painter.setBrush(QBrush(color_widget));
-    painter.setPen(Qt::transparent);
-    QRect rect = this->rect();
-    rect.setWidth(rect.width() - 0);
-    rect.setHeight(rect.height() - 0);
-    painter.drawRoundedRect(rect, 7, 0);
-    //也可用QPainterPath 绘制代替 painter.drawRoundedRect(rect, 15, 15);
-    {
-        QPainterPath painterPath;
-        painterPath.addRoundedRect(rect, 7, 0);
-        painter.drawPath(painterPath);
-    }
+    Q_UNUSED(event);
+    QPainter p(this);
+    p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
+    QPainterPath rectPath;
+    rectPath.addRect(this->rect());
+    p.fillPath(rectPath,QBrush(color_widget));
     QWidget::paintEvent(event);
 }
