@@ -21,6 +21,8 @@
 
 #include <QWidget>
 #include <QPainter>
+#include <QAction>
+#include <QMenu>
 
 namespace Ui {
 class noteHeadMenu;
@@ -35,11 +37,23 @@ public:
     ~noteHeadMenu();
 
     Ui::noteHeadMenu *ui;
-    void paintEvent(QPaintEvent *event);
+
+public:
     QColor color_widget;
+    QAction *m_menuActionDel;
+
+protected:
+    void paintEvent(QPaintEvent *event);
+//    void mouseDoubleClickEvent(QMouseEvent *event);
 
 private:
-    void buttonInit();
+    void btnInit();
+    void slotsInit();
+
+signals:
+    void requestNewNote();
+    void requestShowNote();
+//    void requestFullscreen();
 };
 
 #endif // NOTEHEADMENU_H
