@@ -44,6 +44,15 @@ SidebarClipboardPlugin::SidebarClipboardPlugin(QObject *parent)
         qDebug() << "cannot load translator ukui-feedback_" << QLocale::system().name() << ".qm!";
 
     installEventFilter(this);
+
+//    const QByteArray id("org.ukui.sidebar");
+//    if (QGSettings::isSchemaInstalled(id)) {
+//        QGSettings *m_pGsetting = new QGSettings(id);
+//        m_bPromptBoxBool = m_pGsetting->get("promptboxbool").toBool();
+//    } else {
+//        m_bPromptBoxBool = true;
+//    }
+
     m_bPromptBoxBool = true;
 
     m_pClipboardDb = new clipboardDb();
@@ -67,6 +76,14 @@ SidebarClipboardPlugin::SidebarClipboardPlugin(QObject *parent)
     /* 在点击确认键后判断是否有勾选不再提示这一功能 */
     connect(InternalSignal, &ClipBoardInternalSignal::CheckBoxSelectedSignal, this, [=]() {
         m_bPromptBoxBool = false;
+//        const QByteArray id("org.ukui.sidebar");
+//        if (QGSettings::isSchemaInstalled(id)) {
+//            QGSettings *m_pGsetting = new QGSettings(id);
+//            m_bPromptBoxBool = false;
+//            m_pGsetting->set("promptboxbool",false);
+//        } else {
+//            m_bPromptBoxBool = false;
+//        }
     });
 
     /* 当剪贴板条目发生变化的时候执行该槽函数 */
@@ -95,6 +112,8 @@ SidebarClipboardPlugin::SidebarClipboardPlugin(QObject *parent)
     connect(m_pThread, &QThread::started,this, &SidebarClipboardPlugin::loadClipboardDb);
     m_pThread->start();
 
+//    resetWidgetLabelText();
+
     /* 加载样式表 */
     QFile file(SIDEBAR_CLIPBOARD_QSS_PATH);
     if (file.open(QFile::ReadOnly)) {
@@ -115,7 +134,7 @@ void SidebarClipboardPlugin::createWidget()
     m_pShortcutOperationListWidget->setContentsMargins(0,0,0,0);
 
     m_pSearchWidgetListWidget      = new QListWidget;
-    m_pSearchWidgetListWidget->setFixedSize(400, 42);
+    m_pSearchWidgetListWidget->setFixedSize(400, 50);
     m_pSearchWidgetListWidget->setContentsMargins(0,0,0,0);
 }
 
@@ -189,6 +208,7 @@ void SidebarClipboardPlugin::createFindClipboardWidgetItem()
     QListWidgetItem *pListWidgetItem = new QListWidgetItem;
     pListWidgetItem->setFlags(Qt::NoItemFlags);
     m_pSearchArea = new SearchWidgetItemContent;
+    m_pSearchArea->setFixedHeight(50);
     connect(m_pSearchArea->m_pClearListWidgetButton, &QPushButton::clicked, this, &SidebarClipboardPlugin::removeAllWidgetItem);
 
     connect(m_pSearchArea->m_pLineEditArea, SIGNAL(textChanged(QString)), this, SLOT(searchClipboardLableTextSlots(QString)));
@@ -215,6 +235,10 @@ void SidebarClipboardPlugin::createWidgetEntry()
     if (mimeData->hasImage()) {
         s_pDataHashValue->p_pixmap = new QPixmap((qvariant_cast<QPixmap>(mimeData->imageData())));
         format = IMAGE;
+        if(mimeData->hasText()){
+            text = mimeData->text();
+            format = TEXT;
+        }
         if (nullptr == s_pDataHashValue->p_pixmap) {
            qWarning() << "构造数据类型有错误-->p_pixmap == nullptr";
            return;
@@ -270,7 +294,7 @@ void SidebarClipboardPlugin::createWidgetEntry()
 
     /* hash插入QMimeData，保留原数据 */
     s_pDataHashValue->WidgetEntry  = w;
-    s_pDataHashValue->MimeData = copyMinedata(mimeData);
+    s_pDataHashValue->MimeData = nullptr;
     s_pDataHashValue->Clipbaordformat = format;
     s_pDataHashValue->associatedDb = "";
     if (s_pDataHashValue->Clipbaordformat == TEXT) {
@@ -296,6 +320,7 @@ void SidebarClipboardPlugin::createWidgetEntry()
 
     /* 将按钮与槽对应上 */
     connectWidgetEntryButton(w);
+
     /* 插入剪贴板条目 */
     m_pShortcutOperationListWidget->insertItem(0, pListWidgetItem);
     m_pShortcutOperationListWidget->setItemWidget(pListWidgetItem, w);
@@ -318,7 +343,9 @@ void SidebarClipboardPlugin::AddWidgetEntry(OriginalDataHashValue *s_pDataHashVa
         w->m_pCopyDataLabal->setTextFormat(Qt::PlainText);
         if (s_pDataHashValue->urls.size() == 1) {
             //判断文件类型，根据文件类型去读取主题图标
-            QString filename = catUrlFileName(text);
+//            QString filename = catUrlFileName(text);
+            QUrl texturl(text);
+            QString filename=texturl.fileName();
             filename = setMiddleFormatBody(filename, w);
             w->m_pCopyDataLabal->setText(filename);
             getPixmapListFileIcon(text, w->m_pCopyFileIcon);
@@ -381,6 +408,7 @@ QString SidebarClipboardPlugin::SetFormatBody(QString text, ClipboardWidgetEntry
             }
         }
     }
+
     return formatBody;
 }
 
@@ -477,13 +505,16 @@ bool SidebarClipboardPlugin::substringSposition(QString formatBody, QStringList
 /* 判断Url中当前后缀名，根据后缀名读取图标 */
 QIcon SidebarClipboardPlugin::fileSuffixGetsIcon(QString Url)
 {
+    QUrl texturl(Url);
+    QString  filePath;
     if (Url == nullptr) {
         qWarning() << "传入后缀名有错误， 为空";
     }
     int tmp = m_fileSuffix.size();
     QStringList UrlList = Url.split(".");
     if (UrlList.size() < 2) {
-        QString  filePath = Url.mid(7);
+//        QString  filePath = Url.mid(7);
+        filePath=texturl.toLocalFile();
         QFileInfo fileinfo(filePath);
         if (fileinfo.isFile()) {
             return QIcon::fromTheme("unknown");//返回其余文本图标
@@ -862,7 +893,8 @@ void SidebarClipboardPlugin::editButtonSlots(ClipboardWidgetEntry *w)
     int nRet = EditWidget.exec();
     if (nRet == QDialog::Accepted) {
         QString formatBody = SetFormatBody(EditWidget.m_pEditingArea->toPlainText(), w);  // 设置...字样
-        qDebug () << "formatBody....." << formatBody;
+//        QString formatBody = EditWidget.m_pEditingArea->toPlainText();
+         qDebug () << "formatBody....." << formatBody;
         if (EditWidget.m_pEditingArea->toPlainText() != text) {
             //当编辑后数据改变时，就需要将m_pLabelText中的value改变
             w->m_pCopyDataLabal->setText(formatBody);
@@ -900,7 +932,8 @@ void SidebarClipboardPlugin::fixedWidgetEntrySlots(ClipboardWidgetEntry *w)
         m_pClipboardDb->insertSqlClipbarodDb(s_pDataHashValue->text, s_pDataHashValue->Clipbaordformat, s_pDataHashValue->Sequence);
     } else if (s_pDataHashValue->Clipbaordformat == IMAGE) {
         int seq = m_pClipboardDb->SelectSqlClipbaordDbId();
-        QString url_filepath =  QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + QStringLiteral("/%1.bmp").arg(seq + 1);
+        QString url_filepath =  QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/.config" + QStringLiteral("/%1.bmp").arg(seq + 1);
+        qDebug() << "------------------------------->" << url_filepath;
         s_pDataHashValue->text = "file://" + url_filepath;          //将文件路径已Url的方式保存
         m_pClipboardDb->insertSqlClipbarodDb(s_pDataHashValue->text, s_pDataHashValue->Clipbaordformat, s_pDataHashValue->Sequence);
         s_pDataHashValue->p_pixmap->save(url_filepath, "bmp", 100);
@@ -920,6 +953,10 @@ void SidebarClipboardPlugin::cancelFixedWidgetEntrySLots(ClipboardWidgetEntry *w
     }
     QListWidgetItem *Item = iterationClipboardDataHash(w);
     OriginalDataHashValue *s_pDataHashValue = GetOriginalDataValue(Item);
+    if (s_pDataHashValue->Clipbaordformat ==IMAGE && s_pDataHashValue->associatedDb == DBDATA) {
+        QString DeleteFile = QStringLiteral("rm %1").arg(s_pDataHashValue->text.mid(7));
+        QProcess::execute(DeleteFile);//删除保存在本地的文件
+    }
     m_pClipboardDb->deleteSqlClipboardDb(s_pDataHashValue->text);  //删除数据库中此条数据
     s_pDataHashValue->associatedDb = "";
     w->m_pPopButton->setVisible(true);
@@ -1047,7 +1084,7 @@ void SidebarClipboardPlugin::removeAllWidgetItem()
     }
     /* 判断用户是否勾选了不再提醒这一功能 */
     if (m_bPromptBoxBool) {
-        emit globalClipboardSignal->ClipBoardWidgetEntryEditButtonSignal(); //当点击清楚时，将侧边栏置为不Hide状态
+        emit globalClipboardSignal->ClipBoardWidgetEntryEditButtonSignal(); // 当点击清楚时，将侧边栏置为不Hide状态
         CleanPromptBox PromptBoxWidget;
         int nRet = PromptBoxWidget.exec();
         if (nRet == QDialog::Accepted) {
@@ -1247,7 +1284,9 @@ bool SidebarClipboardPlugin::judgeFileExit(QString fullFilePath)
         qWarning() << "参数错误 ---> 参数类型 Qstring" << fullFilePath;
         return false;
     }
+
     QStringList filePath = fullFilePath.split('\n');
+//    qDebug() << "当前文件路径" << filePath;
     if (filePath.count() == 1) {
         QFileInfo fileInfo(fullFilePath.mid(7));
         if (fileInfo.exists()) {
@@ -1259,8 +1298,6 @@ bool SidebarClipboardPlugin::judgeFileExit(QString fullFilePath)
             QFileInfo fileInfo(filePath[i].mid(7));
             if (fileInfo.exists() && i == tmp - 1) {
                 return true;
-            } else {
-                return false;
             }
         }
     }
@@ -1349,6 +1386,18 @@ void SidebarClipboardPlugin::setEntryItemSize(OriginalDataHashValue* value, Clip
     return;
 }
 
+/* 当监听到主题字体发生变化时，则重新设置label条目的text */
+void SidebarClipboardPlugin::resetWidgetLabelText()
+{
+    const QByteArray id("org.ukui.style");
+    QGSettings * fontSetting = new QGSettings(id);
+    connect(fontSetting, &QGSettings::changed,[=](QString key){
+        if ("systemFont" == key || "systemFontSize" ==key) {
+            searchClipboardLableTextSlots("");
+        }
+    });
+}
+
 void SidebarClipboardPlugin::sortingEntryShow()
 {
     int index = 0;
