@@ -23,81 +23,98 @@
 #include "monitorthread.h"
 #include <QSvgRenderer>
 #include <QDebug>
+#include <QPainter>
+#include "customstylePushbutton2.h"
 
 
 NotificationPlugin::NotificationPlugin()
 {
-    m_bInitialFlag = false;
-    m_bShowTakeIn = false;
-    m_pMainWidget = new QWidget;
-    m_pMainWidget->setObjectName("NotificationCenter");
+    //初始化翻译文件
+    initTrans();
 
+    //初始化界面
+    initUI();
+
+    //新建一个监控dbus消息的线程
+    MonitorThread* pMonitorThread = new MonitorThread(this);
+    QGSettings* pEnablenotice = new QGSettings("org.ukui.control-center.notice", "", this);
+    if(pEnablenotice->get("enable-notice").toBool()) {
+        pMonitorThread->start();
+        pMonitorThread->switchEnable(pEnablenotice->get("enable-notice").toBool());
+    }
+
+    connect(pEnablenotice, &QGSettings::changed, [=](){
+        pMonitorThread->switchEnable(pEnablenotice->get("enable-notice").toBool());
+    });
+
+    return;
+}
+
+
+QWidget* NotificationPlugin::centerWidget()
+{
+    return  m_pMainWidget;
+}
+
+void NotificationPlugin::initTrans()
+{
     QTranslator *translator = new QTranslator;
     if (translator->load(QLocale(), QLatin1String("ukui-sidebar-notification"), QLatin1String("_"), QLatin1String("/usr/share/ukui-sidebar/ukui-sidebar-notification")))
         QApplication::installTranslator(translator);
     else
         qDebug() << "cannot load translator ukui-sidebar-notification_" << QLocale::system().name() << ".qm!";
+}
 
-    //加载样式表
-    QFile file(":/qss/notificationPlugin.css");
-    if (file.open(QFile::ReadOnly))
-    {
-        QString strQss = QLatin1String(file.readAll());
-        file.close();
-        m_pMainWidget->setStyleSheet(strQss);
-    }
+void NotificationPlugin::initUI()
+{
+    m_pMainWidget = new external_widget;
+    m_pMainWidget->setObjectName("NotificationCenter");
 
-    //插件的总VBoxLayout布局器
+    //消息通知模块总VBoxLayout布局器
     QVBoxLayout* pNotificationVBoxLayout = new QVBoxLayout;
     pNotificationVBoxLayout->setContentsMargins(10,21,0,0);
     pNotificationVBoxLayout->setSpacing(0);
 
-    m_pMainWidget->setLayout(pNotificationVBoxLayout);
-
     //装第一行通知中心的Widget
     QWidget* pWidget1= new QWidget;
     pWidget1->setObjectName("NotificationName");
-    pWidget1->setStyleSheet("QWidget{background-color:transparent ;}");
-    //第一行通知中心标题栏，左侧标题“通知中心”，右侧收纳按钮
+    pWidget1->setAttribute(Qt::WA_TranslucentBackground);
+
+    //第一行通知中心标题栏，左侧-标题通知中心，右侧-收纳按钮
     QHBoxLayout* pQHBoxLayout1 = new QHBoxLayout;
     pQHBoxLayout1->setContentsMargins(11,0,28,0);
     pQHBoxLayout1->setSpacing(0);
 
+    //标题-通知中心
     QLabel* pLabel = new QLabel(QObject::tr("Notification center"));
     pLabel->setObjectName("notificationcentername");
+    pLabel->setAttribute(Qt::WA_TranslucentBackground);
 
     //收纳按钮
     m_pTakeInBoxToolButton = new TakeInBoxToolButton();
-//    m_pTakeInBoxToolButton->setObjectName("takein");
-//    m_pTakeInBoxToolButton->setStyleSheet("QToolButton{background-color:rgba(0,0,255,0);}");
-    m_pTakeInBoxToolButton->setStyleSheet("QToolButton:hover{background-color:rgba(255,0,0,1);}");
+    m_pTakeInBoxToolButton->setStyle(new CustomStyle_pushbutton_2("ukui-default"));
     connect(m_pTakeInBoxToolButton, SIGNAL(Sig_clicked()), this, SLOT(onShowTakeInMessage()));
-       //QToolButton添加svg图片
-    m_pSvgRender = new QSvgRenderer(pWidget1);
-    m_pSvgRender->load(QString(":/images/box-24.svg"));
-    m_pTakeInBoxToolButton->setFixedSize(24,24);
-    m_pTakeInBoxToolButton->setIconSize(QSize(24,24));
-    m_pPixmap = new QPixmap(24, 24);
 
-    m_pPixmap->fill(Qt::transparent);
-    QPainter painter(m_pPixmap);
-    m_pSvgRender->render(&painter);
-    m_pTakeInBoxToolButton->setIcon(QIcon(*m_pPixmap));
+    m_pTakeInBoxToolButton->setFixedSize(30,30);
+    m_pTakeInBoxToolButton->setIconSize(QSize(24,24));
+    m_pTakeInBoxToolButton->setIcon(QIcon(":/images/box-24.svg"));
 
     pQHBoxLayout1->addWidget(pLabel, 0, Qt::AlignLeft);
     pQHBoxLayout1->addWidget(m_pTakeInBoxToolButton, 0, Qt::AlignRight);
     pWidget1->setLayout(pQHBoxLayout1);
-//    pWidget1->setStyleSheet("QWidget{background-color:rgba(0,255,0,0);}");
     pNotificationVBoxLayout->addWidget(pWidget1);
 
     //悬浮收纳数标签
-    m_pTakeInCoutLabel = new QLabel(m_pMainWidget);
+    m_pTakeInCoutLabel = new TakeInCoutLabel(m_pMainWidget);
     m_pTakeInCoutLabel->setObjectName("takeincout");
+    m_pTakeInCoutLabel->setFixedSize(23,23);
+
+    QPalette pe1;
+    pe1.setColor(QPalette::WindowText,Qt::black);
+    m_pTakeInCoutLabel->setPalette(pe1);
     m_pTakeInCoutLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
     m_pTakeInCoutLabel->setVisible(false);
-    m_pTakeInCoutLabel->setStyleSheet("QLabel{font-size:11px;"
-                                      "background-color:rgba(61,107,229,1);"
-                                      "border-radius:6px;}");
+
     //添加24px的间距
     QSpacerItem* pVFixedSpacer = new QSpacerItem(10, 24, QSizePolicy::Fixed, QSizePolicy::Fixed);
     pNotificationVBoxLayout->addSpacerItem(pVFixedSpacer);
@@ -110,90 +127,51 @@ NotificationPlugin::NotificationPlugin()
     QHBoxLayout* pQHBoxLayout2 = new QHBoxLayout;
     pQHBoxLayout2->setContentsMargins(12,0,10,8);
 
+    //标签-重要的信息
     m_pNotificationLabel = new QLabel(QObject::tr("Important notice"));
     m_pNotificationLabel->setObjectName("importantnotification");
+    m_pNotificationLabel->setAttribute(Qt::WA_TranslucentBackground);
 
-    QSpacerItem* pHSpacer = new QSpacerItem(300, 10, QSizePolicy::Expanding, QSizePolicy::Fixed);
-
+    //清空按钮
     m_pClearAllToolButton = new QPushButton();
     m_pClearAllToolButton->setObjectName("clearall");
     connect(m_pClearAllToolButton, SIGNAL(clicked()), this, SLOT(onClearAllMessage()));
     m_pClearAllToolButton->setText(QObject::tr("Clean up"));
-//    m_pClearAllToolButton->setStyleSheet("QPushButton{color:rgba(255,255,255,0.91);}"
-    m_pClearAllToolButton->setStyleSheet("QPushButton{"
-                                         "color:rgba(255,255,255,0.91);"
-                                         "font-weight:400;border:0px;"
-                                         "line-height:24px;"
-                                         "font-size:14px;"
-                                         " width:80px;"
-                                         "height:34px;}"
-                                         "QPushButton:hover{"
-                                         "color:rgba(255,255,255,0.91);"
-                                         "background:rgba(255,255,255,0.12);"
-                                         "font-weight:400;border:0px;"
-                                         "line-height:24px;"
-                                         "font-size:14px;"
-                                         " width:80px;"
-                                         "height:34px;}"
-
-                                         "QPushButton:pressed#clearall{"
-                                         "color:rgba(255,255,255,0.91);"
-                                         "background:rgba(255,255,255,0.08);"
-                                         "font-weight:400;border:0px;"
-                                         "line-height:24px;"
-                                         "font-size:14px;"
-                                         " width:80px;"
-                                         "height:34px;}");
-    QSpacerItem* pFixSpacer = new QSpacerItem(5, 10, QSizePolicy::Fixed, QSizePolicy::Fixed);
+    m_pClearAllToolButton->setStyle(new CustomStyle_pushbutton_2("ukui-default"));
+    m_pClearAllToolButton->setVisible(false);
 
+    //设置按钮
     QPushButton* pSettingToolButton = new QPushButton();
     pSettingToolButton->setObjectName("setting");
     connect(pSettingToolButton, SIGNAL(clicked()), this, SLOT(onCallControlPanel()));
     pSettingToolButton->setText(QObject::tr("Set up"));
-    pSettingToolButton->setStyleSheet("QPushButton{"
-                                    "color:rgba(255,255,255,0.91);"
-                                    "font-weight:400;border:0px;"
-                                    "line-height:24px;"
-                                    "font-size:14px;"
-                                    " width:80px;"
-                                    "height:34px;}"
-                                    "QPushButton:hover{"
-                                    "color:rgba(255,255,255,0.91);"
-                                    "background:rgba(255,255,255,0.12);"
-                                    "font-weight:400;border:0px;"
-                                    "line-height:24px;"
-                                    "font-size:14px;"
-                                    " width:80px;"
-                                    "height:34px;}"
+    pSettingToolButton->setStyle(new CustomStyle_pushbutton_2("ukui-default"));
 
-                                    "QPushButton:pressed{"
-                                    "color:rgba(255,255,255,0.91);"
-                                    "background:rgba(255,255,255,0.08);"
-                                    "font-weight:400;border:0px;"
-                                    "line-height:24px;"
-                                    "font-size:14px;"
-                                    " width:80px;"
-                                    "height:34px;}");
+    //布局
+    QSpacerItem* pFixSpacer = new QSpacerItem(5, 10, QSizePolicy::Fixed, QSizePolicy::Fixed);
+    QSpacerItem* pHSpacer = new QSpacerItem(300, 10, QSizePolicy::Expanding, QSizePolicy::Fixed);
     pQHBoxLayout2->addWidget(m_pNotificationLabel, 0, Qt::AlignLeft);
     pQHBoxLayout2->addSpacerItem(pHSpacer);
     pQHBoxLayout2->addWidget(m_pClearAllToolButton, 0, Qt::AlignRight);
     pQHBoxLayout2->addSpacerItem(pFixSpacer);
     pQHBoxLayout2->addWidget(pSettingToolButton, 0, Qt::AlignRight);
     pWidget2->setLayout(pQHBoxLayout2);
-    pWidget2->setStyleSheet("QWidget{background-color:transparent ;}");
     pNotificationVBoxLayout->addWidget(pWidget2, 0);
 
-    //消息列表部件，用于装消息列表的
-    m_pMsgListWidget = new QWidget;
+    //消息列表widget
+    m_pMsgListWidget = new inside_widget;
+    m_pMsgListWidget->setFixedSize(390,546);
     pNotificationVBoxLayout->addWidget(m_pMsgListWidget, 1);
-    m_pMsgListWidget->setStyleSheet("QWidget{background-color:transparent ;}");
+    m_pMsgListWidget->setParent(m_pMainWidget);
+
     //消息列表部件，用于装两个消息列表的,浮动在m_pMsgListWidget里面
-    m_pMsgDoubleListWidget = new QWidget(m_pMsgListWidget);
+    m_pMsgDoubleListWidget = new inside_widget(m_pMsgListWidget);
     QHBoxLayout* pMsgDoubleListHBoxLayout = new QHBoxLayout;
     pMsgDoubleListHBoxLayout->setContentsMargins(0, 0, 0, 0);
     pMsgDoubleListHBoxLayout->setSpacing(0);
     m_pMsgDoubleListWidget->setLayout(pMsgDoubleListHBoxLayout);
-    m_pMsgDoubleListWidget->setStyleSheet("QWidget{background-color:transparent ;}");
+    m_pMsgDoubleListWidget->setAttribute(Qt::WA_TranslucentBackground);
+
     //双列表部件切换动画
     m_pSwitchAnimation = new QPropertyAnimation(m_pMsgDoubleListWidget, "geometry", this);
     m_pSwitchAnimation->setDuration(300);
@@ -201,31 +179,31 @@ NotificationPlugin::NotificationPlugin()
 
     //通知列表
     m_pQScrollAreaNotify = new ScrollAreaWidget();
-    m_pQScrollAreaNotify->setStyleSheet("QWidget{background:transparent;}");
+    m_pQScrollAreaNotify->setAttribute(Qt::WA_TranslucentBackground);
+    m_pQScrollAreaNotify->setFrameShape(QFrame::NoFrame);
     m_pQScrollAreaNotify->setFixedWidth(390);
-
     m_pScrollAreaNotifyVBoxLayout = new QVBoxLayout();
     m_pScrollAreaNotifyVBoxLayout->setContentsMargins(0, 0, 0, 0);
-    m_pScrollAreaNotifyVBoxLayout->setSpacing(0);
+    m_pScrollAreaNotifyVBoxLayout->setSpacing(6);
 
     //通知列表的最内层部件
-    QWidget* pInQWidget = new QWidget();
+    inside_widget* pInQWidget = new inside_widget();
     pInQWidget->setObjectName("QScrollAreaInQWidget");
     pInQWidget->setLayout(m_pScrollAreaNotifyVBoxLayout);
-    pInQWidget->setStyleSheet("QWidget{background-color:transparent ;}");
+    pInQWidget->setAttribute(Qt::WA_TranslucentBackground);
     m_pQScrollAreaNotify->setWidget(pInQWidget);
-
     m_pMessageCenterLabel = new QLabel(QObject::tr("No new notifications"));
-    m_pMessageCenterLabel->setStyleSheet("QLabel{color:rgba(255,255,255,0.91);background-color:transparent;padding:119px 0px 0px 0px;font-size:14px;}");
-    m_pScrollAreaNotifyVBoxLayout->addWidget(m_pMessageCenterLabel, 0, Qt::AlignHCenter);
-
+    m_pMessageCenterLabel->setStyleSheet("background:transparent");
+    m_pScrollAreaNotifyVBoxLayout->addWidget(m_pMessageCenterLabel, 4, Qt::AlignCenter);
+    m_pMessageCenterLabel->setAttribute(Qt::WA_TranslucentBackground);
     QSpacerItem* pVSpacer = new QSpacerItem(10, 1, QSizePolicy::Fixed, QSizePolicy::Expanding);
     m_pScrollAreaNotifyVBoxLayout->addSpacerItem(pVSpacer);
     pMsgDoubleListHBoxLayout->addWidget(m_pQScrollAreaNotify, 0);
 
     //收纳列表
     m_pQScrollAreaTakeIn = new ScrollAreaWidget();
-    m_pQScrollAreaTakeIn->setStyleSheet("QWidget{background:transparent;}");
+    m_pQScrollAreaTakeIn->setAttribute(Qt::WA_TranslucentBackground);
+    m_pQScrollAreaTakeIn->setFrameShape(QFrame::NoFrame);
     m_pQScrollAreaTakeIn->setFixedWidth(390);
 
     m_pScrollAreaTakeInVBoxLayout = new QVBoxLayout();
@@ -233,80 +211,49 @@ NotificationPlugin::NotificationPlugin()
     m_pScrollAreaTakeInVBoxLayout->setSpacing(0);
 
     //收纳列表的最内层部件
-    QWidget* pTakeInQWidget = new QWidget();
+    inside_widget* pTakeInQWidget = new inside_widget();
     pTakeInQWidget->setObjectName("QScrollAreaInQWidget");
     pTakeInQWidget->setLayout(m_pScrollAreaTakeInVBoxLayout);
+    pTakeInQWidget->setAttribute(Qt::WA_TranslucentBackground);
     m_pQScrollAreaTakeIn->setWidget(pTakeInQWidget);
-
     m_pTakeinMessageCenterLabel = new QLabel(QObject::tr("No unimportant notice"));
-    m_pTakeinMessageCenterLabel->setStyleSheet("QLabel{color:rgba(255,255,255,0.91);background-color:transparent; padding:119px 0px 0px 0px;font-size:14px;}");
-    m_pScrollAreaTakeInVBoxLayout->addWidget(m_pTakeinMessageCenterLabel, 0, Qt::AlignHCenter);
+    m_pTakeinMessageCenterLabel->setAttribute(Qt::WA_TranslucentBackground);
 
+    m_pScrollAreaTakeInVBoxLayout->addWidget(m_pTakeinMessageCenterLabel, 4, Qt::AlignCenter);
     QSpacerItem* pVSpacer2 = new QSpacerItem(10, 1, QSizePolicy::Fixed, QSizePolicy::Expanding);
     m_pScrollAreaTakeInVBoxLayout->addSpacerItem(pVSpacer2);
     pMsgDoubleListHBoxLayout->addWidget(m_pQScrollAreaTakeIn, 0);
 
     //通知中心最底部固定9px的空白
     QSpacerItem* pVBottomSpacer = new QSpacerItem(9, 9, QSizePolicy::Fixed, QSizePolicy::Fixed);
-    pNotificationVBoxLayout->addSpacerItem(pVBottomSpacer);   
+    pNotificationVBoxLayout->addSpacerItem(pVBottomSpacer);
+    m_pMainWidget->setLayout(pNotificationVBoxLayout);
 
-    //新建一个监控dbus消息的线程
-    MonitorThread* pMonitorThread = new MonitorThread(this);
-    m_pEnablenotice = new QGSettings("org.ukui.control-center.notice");
-    if(m_pEnablenotice->get("enable-notice").toBool())
-    pMonitorThread->start();
-
-    connect(m_pEnablenotice,&QGSettings::changed,[=](){
-    if(m_pEnablenotice->get("enable-notice").toBool())
-    {
-        if(!pMonitorThread->isRunning())
-            pMonitorThread->start();
-    }
-    else
-    {
-        if(pMonitorThread->isRunning())
-            pMonitorThread->exit();
-    }
-    });
-
-    return;
-}
-
-
-QWidget* NotificationPlugin::centerWidget()
-{
-    return  m_pMainWidget;
 }
 
 void NotificationPlugin::showNotification()
 {
-    if(false == m_bInitialFlag)
-    {
+    if (false == m_bInitialFlag) {
         m_bInitialFlag = true;
         qDebug()<<"NotificationPlugin::showNotification 通知列表的高度"<<m_pMsgListWidget->height() <<m_pMsgListWidget->width();
-        //m_pMsgDoubleListWidget->setFixedHeight(m_pMsgListWidget->height());
         m_pMsgDoubleListWidget->setGeometry(0, 0, m_pMsgListWidget->width()*2, m_pMsgListWidget->height());
     }
     //上面不需要判断，因为在隐藏时，已经切换至通知中心，m_bShowTakeIn为false
-    for(int i = 0; i < m_listAppMsg.count(); i++)
-    {
+    for (int i = 0; i < m_listAppMsg.count(); i++) {
         AppMsg* pAppMsg = m_listAppMsg.at(i);
         pAppMsg->updateAppPushTime();
     }
-
 }
 
 void NotificationPlugin::hideNotification()
 {
     //侧边栏隐藏时，如果已经显示收纳盒，则切换至通知列表
-    if(true == m_bShowTakeIn)
-    {
+    if (true == m_bShowTakeIn) {
         onShowTakeInMessage();
     }
 
     //隐藏时，因为上面已切换至通知列表，所以只需将通知列表都折叠即可
-    for(int i = 0; i < m_listAppMsg.count(); i++)
-    {
+    for (int i = 0; i < m_listAppMsg.count(); i++) {
         AppMsg* pAppMsg = m_listAppMsg.at(i);
         pAppMsg->setAppFold();
     }
@@ -316,11 +263,9 @@ void NotificationPlugin::hideNotification()
 AppMsg* NotificationPlugin::getAppMsgAndIndexByName(QString strAppName, int& nIndex)
 {
     AppMsg* pAppMsg = NULL;
-    for(int i = 0; i < m_listAppMsg.count(); i++)
-    {
+    for (int i = 0; i < m_listAppMsg.count(); i++) {
         AppMsg* pTmpAppMsg = m_listAppMsg.at(i);
-        if(strAppName == pTmpAppMsg->getAppName())
-        {
+        if (strAppName == pTmpAppMsg->getAppName()) {
             pAppMsg = pTmpAppMsg;
             nIndex = i;
             break;
@@ -329,7 +274,8 @@ AppMsg* NotificationPlugin::getAppMsgAndIndexByName(QString strAppName, int& nIn
     return pAppMsg;
 }
 
-uint NotificationPlugin::onAddSingleNotify(QString strAppName, QString strIconPath, QString strSummary, QString strBody, QDateTime dateTime, int maxNum, bool bNewNotificationFlag)
+uint NotificationPlugin::onAddSingleNotify(QString strAppName, QString strIconPath, QString strSummary, \
+                                           QString strBody, QDateTime dateTime, int maxNum, bool bNewNotificationFlag)
 {
     if(true == bNewNotificationFlag)
     {
@@ -337,10 +283,10 @@ uint NotificationPlugin::onAddSingleNotify(QString strAppName, QString strIconPa
     }
 
     //当列表信息为空表明第一次来通知，列表个数为2，一个表面是“没有新通知标签”，一个是底部弹簧
-    if(0 == m_listAppMsg.count() && 2 == m_pScrollAreaNotifyVBoxLayout->count())
-    {
+    if (0 == m_listAppMsg.count() && 2 == m_pScrollAreaNotifyVBoxLayout->count()) {
         m_pScrollAreaNotifyVBoxLayout->removeWidget(m_pMessageCenterLabel);
         m_pMessageCenterLabel->setVisible(false);
+        m_pClearAllToolButton->setVisible(true);
     }
 
     int nIndex = -1;
@@ -348,18 +294,14 @@ uint NotificationPlugin::onAddSingleNotify(QString strAppName, QString strIconPa
     AppMsg* pAppMsg = getAppMsgAndIndexByName(strAppName, nIndex);
 
     //如果不存在，则新建一个AppMsg消息,并且直接置顶
-    if(NULL == pAppMsg)
-    {
+    if (NULL == pAppMsg) {
         pAppMsg = new AppMsg(this, strAppName);
-    }
-    else
-    {
+    } else {
         m_listAppMsg.removeAt(nIndex);
         m_pScrollAreaNotifyVBoxLayout->removeWidget(pAppMsg);
     }
 
-    if(true == bNewNotificationFlag)
-    {
+    if (true == bNewNotificationFlag) {
         pAppMsg->setMaxNumMsg(maxNum);
     }
 
@@ -367,11 +309,9 @@ uint NotificationPlugin::onAddSingleNotify(QString strAppName, QString strIconPa
     pAppMsg->addSingleMsg(strIconPath, strSummary, dateTime, strBody);
 
     int uIndex = m_listAppMsg.count();
-    for(int i = m_listAppMsg.count() - 1; i >= 0; i--)
-    {
+    for (int i = m_listAppMsg.count() - 1; i >= 0; i--) {
         AppMsg* pTmpAppMsg = m_listAppMsg.at(i);
-        if(pAppMsg->getAppPushTime() < pTmpAppMsg->getAppPushTime())
-        {
+        if (pAppMsg->getAppPushTime() < pTmpAppMsg->getAppPushTime()) {
             break;
         }
         uIndex = i;
@@ -381,31 +321,24 @@ uint NotificationPlugin::onAddSingleNotify(QString strAppName, QString strIconPa
     m_pScrollAreaNotifyVBoxLayout->insertWidget(uIndex, pAppMsg);
 
     //如果是新通知，有必要对通知列表更新推送时间；如果是恢复，说明在收纳盒中，所以更新收纳盒中的推送时间
-    if(true == bNewNotificationFlag)
-    {
-        for(int i = 0; i < m_listAppMsg.count(); i++)
-        {
+    if (true == bNewNotificationFlag) {
+        for (int i = 0; i < m_listAppMsg.count(); i++) {
             AppMsg* pTmpAppMsg = m_listAppMsg.at(i);
             pTmpAppMsg->updateAppPushTime();
         }
-    }
-    else
-    {
-        for(int i = 0; i < m_listTakeInAppMsg.count(); i++)
-        {
+    } else {
+        for (int i = 0; i < m_listTakeInAppMsg.count(); i++) {
             AppMsg* pTmpAppMsg = m_listTakeInAppMsg.at(i);
             pTmpAppMsg->updateAppPushTime();
         }
     }
-
     return 1;
 }
 
 void NotificationPlugin::onCountTakeInBitAndUpate() //统计收纳位数并更新至右上角提示
 {
     int nCount = 0;
-    for(int i = 0; i < m_listTakeInAppMsg.count(); i++)
-    {
+    for (int i = 0; i < m_listTakeInAppMsg.count(); i++) {
         AppMsg* pTmpAppMsg = m_listTakeInAppMsg.at(i);
         nCount = nCount + pTmpAppMsg->getSingleMsgCount();
     }
@@ -414,15 +347,11 @@ void NotificationPlugin::onCountTakeInBitAndUpate() //统计收纳位数并更
 
     //收纳数的位数
     int nBit = 1;
-    if(nCount > 999)
-    {
+    if (nCount > 999) {
         nBit = 3;
         strCount = "...";
-    }
-    else
-    {
-        while(nCount >= 10)
-        {
+    } else {
+        while (nCount >= 10) {
             nCount = nCount / 10;
             nBit++;
         }
@@ -430,8 +359,7 @@ void NotificationPlugin::onCountTakeInBitAndUpate() //统计收纳位数并更
 
     m_pTakeInCoutLabel->setGeometry(361, 21, (6 + 6 * nBit), 12);
     m_pTakeInCoutLabel->setText(strCount);
-    if(false == m_bShowTakeIn)
-    {
+    if (false == m_bShowTakeIn) {
         m_pTakeInCoutLabel->setVisible(true);
     }
     return;
@@ -440,8 +368,7 @@ void NotificationPlugin::onCountTakeInBitAndUpate() //统计收纳位数并更
 void NotificationPlugin::onClearAppMsg(AppMsg* pAppMsg)
 {
     int nIndex = m_listAppMsg.indexOf(pAppMsg);
-    if(-1 == nIndex)
-    {
+    if (-1 == nIndex) {
         qDebug()<<"NotificationPlugin::onClearAppMsg 在通知链表中未找到pSingleMsg指针";
         return;
     }
@@ -450,10 +377,10 @@ void NotificationPlugin::onClearAppMsg(AppMsg* pAppMsg)
     m_pScrollAreaNotifyVBoxLayout->removeWidget(pAppMsg);
     pAppMsg->deleteLater();
 
-    if(0 == m_listAppMsg.count() && 1 == m_pScrollAreaNotifyVBoxLayout->count())
-    {
+    if (0 == m_listAppMsg.count() && 1 == m_pScrollAreaNotifyVBoxLayout->count()) {
         m_pMessageCenterLabel->setVisible(true);
-        m_pScrollAreaNotifyVBoxLayout->insertWidget(0, m_pMessageCenterLabel, 0, Qt::AlignHCenter);
+        m_pScrollAreaNotifyVBoxLayout->insertWidget(0, m_pMessageCenterLabel, 4, Qt::AlignHCenter);
+        m_pClearAllToolButton->setVisible(false);
     }
 
     return;
@@ -462,41 +389,34 @@ void NotificationPlugin::onClearAppMsg(AppMsg* pAppMsg)
 void NotificationPlugin::onClearAllMessage()
 {
     //当展示通知列表时
-    if(false == m_bShowTakeIn)
-    {
-        while (m_listAppMsg.count() > 0)
-        {
+    if (false == m_bShowTakeIn) {
+        while (m_listAppMsg.count() > 0) {
             AppMsg* pSingleMsg = m_listAppMsg.at(0);
             m_pScrollAreaNotifyVBoxLayout->removeWidget(pSingleMsg);
             pSingleMsg->deleteLater();
             m_listAppMsg.removeAt(0);
         }
 
-        if(1 == m_pScrollAreaNotifyVBoxLayout->count())
-        {
+        if (1 == m_pScrollAreaNotifyVBoxLayout->count()) {
             m_pMessageCenterLabel->setVisible(true);
-            m_pScrollAreaNotifyVBoxLayout->insertWidget(0, m_pMessageCenterLabel, 0, Qt::AlignHCenter);
+            m_pScrollAreaNotifyVBoxLayout->insertWidget(0, m_pMessageCenterLabel, 4, Qt::AlignHCenter);
+            m_pClearAllToolButton->setVisible(false);
         }
-
-    }
-    else
-    {
-        while (m_listTakeInAppMsg.count() > 0)
-        {
+    } else {
+        while (m_listTakeInAppMsg.count() > 0) {
             AppMsg* pSingleMsg = m_listTakeInAppMsg.at(0);
             m_pScrollAreaTakeInVBoxLayout->removeWidget(pSingleMsg);
             pSingleMsg->deleteLater();
             m_listTakeInAppMsg.removeAt(0);
         }
 
-        if(1 == m_pScrollAreaTakeInVBoxLayout->count())
-        {
+        if (1 == m_pScrollAreaTakeInVBoxLayout->count()) {
             m_pTakeinMessageCenterLabel->setVisible(true);
-            m_pScrollAreaTakeInVBoxLayout->insertWidget(0, m_pTakeinMessageCenterLabel, 0, Qt::AlignHCenter);
+            m_pScrollAreaTakeInVBoxLayout->insertWidget(0, m_pTakeinMessageCenterLabel, 4, Qt::AlignHCenter);
+            m_pClearAllToolButton->setVisible(false);
         }
         onCountTakeInBitAndUpate();
     }
-
     return;
 }
 
@@ -505,8 +425,7 @@ void NotificationPlugin::onCloseAppMsg(QString strAppName)
 {
     int nIndex = -1;
     AppMsg* pAppMsg = getAppMsgAndIndexByName(strAppName, nIndex);
-    if(NULL != pAppMsg)
-    {
+    if (NULL != pAppMsg) {
         onClearAppMsg(pAppMsg);
     }
 
@@ -523,16 +442,14 @@ void NotificationPlugin::onUpdateAppMaxNum(QString strAppName, int maxNum)
 {
     int nIndex = -1;
     AppMsg* pAppMsg = getAppMsgAndIndexByName(strAppName, nIndex);
-    if(NULL != pAppMsg)
-    {
+    if (NULL != pAppMsg) {
         pAppMsg->setMaxNumMsg(maxNum);
         pAppMsg->deleteExceedingMsg();
     }
 
     //通过查找m_listTakeInAppMsg列表看该app是否已存在
     AppMsg* pTakeinAppMsg = getTakeinAppMsgAndIndexByName(strAppName, nIndex);
-    if(NULL != pTakeinAppMsg)
-    {
+    if (NULL != pTakeinAppMsg) {
         pTakeinAppMsg->setMaxNumMsg(maxNum);
         pTakeinAppMsg->deleteExceedingMsg();
     }
@@ -541,11 +458,9 @@ void NotificationPlugin::onUpdateAppMaxNum(QString strAppName, int maxNum)
 AppMsg* NotificationPlugin::getTakeinAppMsgAndIndexByName(QString strAppName, int& nIndex)
 {
     AppMsg* pAppMsg = NULL;
-    for(int i = 0; i < m_listTakeInAppMsg.count(); i++)
-    {
+    for (int i = 0; i < m_listTakeInAppMsg.count(); i++) {
         AppMsg* pTmpAppMsg = m_listTakeInAppMsg.at(i);
-        if(strAppName == pTmpAppMsg->getAppName())
-        {
+        if (strAppName == pTmpAppMsg->getAppName()) {
             pAppMsg = pTmpAppMsg;
             nIndex = i;
             break;
@@ -557,40 +472,34 @@ AppMsg* NotificationPlugin::getTakeinAppMsgAndIndexByName(QString strAppName, in
 void NotificationPlugin::onTakeInSingleNotify(QString strAppName, QString strIcon, QString strSummary, QString strBody, QDateTime dateTime, int maxNum, bool bNewTakeinFlag)
 {
     //当列表信息为空表明第一次来通知，列表个数为2，一个表面是“没有新通知标签”，一个是底部弹簧
-    if(0 == m_listTakeInAppMsg.count() && 2 == m_pScrollAreaTakeInVBoxLayout->count())
-    {
+    if (0 == m_listTakeInAppMsg.count() && 2 == m_pScrollAreaTakeInVBoxLayout->count()) {
         m_pScrollAreaTakeInVBoxLayout->removeWidget(m_pTakeinMessageCenterLabel);
         m_pTakeinMessageCenterLabel->setVisible(false);
+        m_pClearAllToolButton->setVisible(true);
     }
 
     int nIndex = -1;
     //通过查找m_listTakeInAppMsg列表看该app是否已存在
     AppMsg* pAppMsg = getTakeinAppMsgAndIndexByName(strAppName, nIndex);
     //如果不存在，则新建一个AppMsg消息
-    if(NULL == pAppMsg)
-    {
+    if (NULL == pAppMsg) {
         pAppMsg = new AppMsg(this, strAppName, true);
-    }
-    else
-    {
+    } else {
         //如果找到该收纳应用，则先移除，后面根据时间插入
         m_listTakeInAppMsg.removeAt(nIndex);
         m_pScrollAreaTakeInVBoxLayout->removeWidget(pAppMsg);
     }
 
-    if(true == bNewTakeinFlag)
-    {
+    if (true == bNewTakeinFlag) {
         pAppMsg->setMaxNumMsg(maxNum);
     }
     pAppMsg->addSingleMsg(strIcon, strSummary, dateTime, strBody);
 
 
     int uIndex = m_listTakeInAppMsg.count();
-    for(int i = m_listTakeInAppMsg.count() - 1; i >= 0; i--)
-    {
+    for (int i = m_listTakeInAppMsg.count() - 1; i >= 0; i--) {
         AppMsg* pTmpAppMsg = m_listTakeInAppMsg.at(i);
-        if(pAppMsg->getAppPushTime() < pTmpAppMsg->getAppPushTime())
-        {
+        if (pAppMsg->getAppPushTime() < pTmpAppMsg->getAppPushTime()) {
             break;
         }
         uIndex = i;
@@ -600,14 +509,11 @@ void NotificationPlugin::onTakeInSingleNotify(QString strAppName, QString strIco
     m_pScrollAreaTakeInVBoxLayout->insertWidget(uIndex, pAppMsg);
 
     //收纳的时候没必要对收纳列表更新，可以对通知列表更新时间，反正点击进入收纳盒时，会更新收纳列表
-    for(int i = 0; i < m_listAppMsg.count(); i++)
-    {
+    for (int i = 0; i < m_listAppMsg.count(); i++) {
         AppMsg* pTmpAppMsg = m_listAppMsg.at(i);
         pTmpAppMsg->updateAppPushTime();
     }
-
     onCountTakeInBitAndUpate();
-
     return;
 }
 
@@ -615,8 +521,7 @@ void NotificationPlugin::onTakeInSingleNotify(QString strAppName, QString strIco
 void NotificationPlugin::onClearTakeInAppMsg(AppMsg* pAppMsg)
 {
     int nIndex = m_listTakeInAppMsg.indexOf(pAppMsg);
-    if(-1 == nIndex)
-    {
+    if (-1 == nIndex) {
         qDebug()<<"NotificationPlugin::onClearTakeInAppMsg 在收纳链表中未找到pSingleMsg指针";
         return;
     }
@@ -627,10 +532,10 @@ void NotificationPlugin::onClearTakeInAppMsg(AppMsg* pAppMsg)
 
     onCountTakeInBitAndUpate();
 
-    if(0 == m_listTakeInAppMsg.count() && 1 == m_pScrollAreaTakeInVBoxLayout->count())
-    {
+    if (0 == m_listTakeInAppMsg.count() && 1 == m_pScrollAreaTakeInVBoxLayout->count()) {
         m_pTakeinMessageCenterLabel->setVisible(true);
-        m_pScrollAreaTakeInVBoxLayout->insertWidget(0, m_pTakeinMessageCenterLabel, 0, Qt::AlignHCenter);
+        m_pScrollAreaTakeInVBoxLayout->insertWidget(0, m_pTakeinMessageCenterLabel, 4, Qt::AlignHCenter);
+        m_pClearAllToolButton->setVisible(false);
     }
     return;
 }
@@ -640,20 +545,16 @@ void NotificationPlugin::onCallControlPanel()
     QProcess p(0);
     p.startDetached("ukui-control-center -n");
     p.waitForStarted();
-
     return;
 }
 
 void NotificationPlugin::onShowTakeInMessage()
 {
-    if(false == m_bShowTakeIn)
-    {
+    if (false == m_bShowTakeIn) {
         m_pSwitchAnimation->setStartValue(QRect(0, 0, m_pMsgListWidget->width()*2, m_pMsgListWidget->height()));
         m_pSwitchAnimation->setEndValue(QRect(0 - m_pMsgListWidget->width(), 0, m_pMsgListWidget->width()*2, m_pMsgListWidget->height()));
         m_pSwitchAnimation->start();
-    }
-    else
-    {
+    } else {
         m_pSwitchAnimation->setStartValue(QRect(0 - m_pMsgListWidget->width(), 0, m_pMsgListWidget->width()*2, m_pMsgListWidget->height()));
         m_pSwitchAnimation->setEndValue(QRect(0, 0, m_pMsgListWidget->width()*2, m_pMsgListWidget->height()));
         m_pSwitchAnimation->start();
@@ -663,64 +564,167 @@ void NotificationPlugin::onShowTakeInMessage()
 //收纳盒按钮切换动画完成后处理
 void NotificationPlugin::onSwitchMsgBoxFinish()
 {
-    if(false == m_bShowTakeIn)
-    {
+    if (false == m_bShowTakeIn) {
         m_bShowTakeIn = true;
         m_pNotificationLabel->setText(QObject::tr("Unimportant notice"));
-
-        m_pSvgRender->load(QString(":/images/exitbox-24.svg"));
-        m_pPixmap->fill(Qt::transparent);
-        QPainter painter(m_pPixmap);
-        m_pSvgRender->render(&painter);
-        m_pTakeInBoxToolButton->setIcon(QIcon(*m_pPixmap));
+        if(m_pTakeinMessageCenterLabel->isVisible()) {
+            m_pClearAllToolButton->setVisible(false);
+        } else {
+            m_pClearAllToolButton->setVisible(true);
+        }
+        m_pTakeInBoxToolButton->setIcon(QIcon(":/images/exitbox-24.svg"));
         m_pTakeInBoxToolButton->setEnterFlags(m_bShowTakeIn);
-
         m_pTakeInCoutLabel->setVisible(false);
 
         //当切换至收纳盒时，先将各个收纳应用更新下时间
-        for(int i = 0; i < m_listTakeInAppMsg.count(); i++)
-        {
+        for (int i = 0; i < m_listTakeInAppMsg.count(); i++) {
             AppMsg* pAppMsg = m_listTakeInAppMsg.at(i);
             pAppMsg->updateAppPushTime();
         }
 
         //再将各个通知应用折叠起来
-        for(int i = 0; i < m_listAppMsg.count(); i++)
-        {
+        for (int i = 0; i < m_listAppMsg.count(); i++) {
             AppMsg* pAppMsg = m_listAppMsg.at(i);
             pAppMsg->setAppFold();
         }
-    }
-    else
-    {
+    } else {
         m_bShowTakeIn = false;
         m_pNotificationLabel->setText(QObject::tr("Important notice"));
+        if(m_pMessageCenterLabel->isVisible()) {
+            m_pClearAllToolButton->setVisible(false);
+        } else {
+            m_pClearAllToolButton->setVisible(true);
+        }
 
-        m_pSvgRender->load(QString(":/images/box-24.svg"));
-        m_pPixmap->fill(Qt::transparent);
-        QPainter painter(m_pPixmap);
-        m_pSvgRender->render(&painter);
-        m_pTakeInBoxToolButton->setIcon(QIcon(*m_pPixmap));
+        m_pTakeInBoxToolButton->setIcon(QIcon(":/images/box-24.svg"));
         m_pTakeInBoxToolButton->setEnterFlags(m_bShowTakeIn);
 
-        if(m_listTakeInAppMsg.count() > 0)
-        {
+        if (m_listTakeInAppMsg.count() > 0) {
             m_pTakeInCoutLabel->setVisible(true);
         }
 
         //当切换至通知列表时，先将各个通知应用更新下时间
-        for(int i = 0; i < m_listAppMsg.count(); i++)
-        {
+        for (int i = 0; i < m_listAppMsg.count(); i++) {
             AppMsg* pAppMsg = m_listAppMsg.at(i);
             pAppMsg->updateAppPushTime();
         }
 
         //再将各个收纳应用折叠起来
-        for(int i = 0; i < m_listTakeInAppMsg.count(); i++)
-        {
+        for (int i = 0; i < m_listTakeInAppMsg.count(); i++) {
             AppMsg* pAppMsg = m_listTakeInAppMsg.at(i);
             pAppMsg->setAppFold();
         }
     }
 }
 
+external_widget::external_widget()
+{
+    initGsettingValue();
+    initGsettingTransparency();
+}
+
+void external_widget::initGsettingTransparency()
+{
+    if(QGSettings::isSchemaInstalled(UKUI_TRANSPARENCY_SETTING)) {
+        m_pTransparency = new QGSettings(UKUI_TRANSPARENCY_SETTING);
+        m_dTranSparency = m_pTransparency->get("transparency").toDouble();
+        connect(m_pTransparency, &QGSettings::changed, this, [=](QString value) {
+            m_dTranSparency = m_pTransparency->get("transparency").toDouble();;
+        });
+    }
+}
+
+void external_widget::initGsettingValue()
+{
+    const QByteArray id(STYLE_FONT_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id))
+        m_pStyleGsetting = new QGSettings(id);
+}
+
+void external_widget::paintEvent(QPaintEvent *e)
+{
+    QPainter p(this);
+    QRect rect = this->rect();
+    p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
+    p.setBrush(QBrush(QColor(220,220,220,255)));
+
+    QString m_style = "ukui-light";
+    const QByteArray id(STYLE_FONT_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id))
+         m_style = m_pStyleGsetting->get("style-name").toString();
+
+    if (m_style=="ukui-light")
+        p.setBrush(QBrush(QColor(220,220,220)));
+    else
+        p.setBrush(QBrush(QColor(20,20,20)));
+
+    p.setOpacity(m_dTranSparency);
+    p.setPen(Qt::NoPen);
+    p.drawRoundedRect(rect,0,0);
+
+}
+
+inside_widget::inside_widget(QWidget *parent) : QWidget(parent)
+{
+      initGsettingValue();
+      initGsettingTransparency();
+}
+
+void inside_widget::initGsettingTransparency()
+{
+    if (QGSettings::isSchemaInstalled(UKUI_TRANSPARENCY_SETTING)) {
+        m_pTransparency = new QGSettings(UKUI_TRANSPARENCY_SETTING);
+        m_dTranSparency = m_pTransparency->get("transparency").toDouble();
+        connect(m_pTransparency, &QGSettings::changed, this, [=](QString value) {
+            m_dTranSparency = m_pTransparency->get("transparency").toDouble();;
+        });
+    }
+}
+
+void inside_widget::initGsettingValue()
+{
+    const QByteArray id(STYLE_FONT_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id))
+        m_pStyleGsetting = new QGSettings(id);
+}
+
+void inside_widget::paintEvent(QPaintEvent *e)
+{
+    QPainter p(this);
+    QRect rect = this->rect();
+    p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
+
+    QString m_style = "ukui-light";
+    const QByteArray id(STYLE_FONT_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id))
+         m_style = m_pStyleGsetting->get("style-name").toString();
+
+    if (m_style=="ukui-light")
+        p.setBrush(QBrush(QColor(220,220,220)));
+    else
+        p.setBrush(QBrush(QColor(20,20,20)));
+
+    p.setOpacity(m_dTranSparency);
+    p.setPen(Qt::NoPen);
+    p.drawRoundedRect(rect,0,0);
+    QWidget::paintEvent(e);
+}
+
+TakeInCoutLabel::TakeInCoutLabel(QWidget *parent) : QLabel(parent)
+{
+
+}
+
+
+void TakeInCoutLabel::paintEvent(QPaintEvent *e)
+{
+    QPainter p(this);
+    QRect rect = this->rect();
+    p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
+    p.setBrush(QBrush(QColor(255,255,255)));
+    p.setOpacity(0.7);
+    p.setPen(Qt::NoPen);
+    p.drawRoundedRect(rect,20,20);
+    QLabel::paintEvent(e);
+}
+
