@@ -28,10 +28,16 @@
 #include <QDebug>
 #include <QTimer>
 #include <QThread>
+#include <QGSettings>
+
+#define STYLE_FONT_SCHEMA "org.ukui.style"
+#define SYSTEM_FONT_EKY "system-font-size"
+#define SYSTEM_NAME_KEY "system-font"
 
 
 SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, QString strSummary, QDateTime dateTime, QString strBody, bool bTakeInFlag)
 {
+    listenTimeZone();
     m_bMain = true;                 //默认是主窗口
     m_bFold = true;                 //默认折叠状态
     m_strIconPath = strIconPath;
@@ -41,7 +47,9 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     m_dateTime = dateTime;
     m_uNotifyTime = dateTime.toTime_t();
     m_bTakeInFlag = bTakeInFlag;
-    m_bTimeFormat = true;
+
+    initTimeFormatGsetting();
+    initGsettingValue();
 
     connect(this, SIGNAL(Sig_setAppFoldFlag(bool)), pParent, SLOT(setAppFoldFlag(bool)));
     connect(this, SIGNAL(Sig_onDeleSingleMsg(SingleMsg*)), pParent, SLOT(onDeleSingleMsg(SingleMsg*)));
@@ -61,9 +69,10 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     m_pAppVLaout->setSpacing(0);
     m_pSingleWidget = new QWidget(this);
     m_pSingleWidget->setObjectName("SingleNotification");
+    m_pSingleWidget->setAttribute(Qt::WA_TranslucentBackground);
 
     m_pAnimationBaseMapWidget = new QWidget(this);
-    m_pAnimationBaseMapWidget->setStyleSheet("background:transparent;");
+    m_pAnimationBaseMapWidget->setAttribute(Qt::WA_TranslucentBackground);
 
     //单条消息总体垂直布局器
     QVBoxLayout* pMainVLaout = new QVBoxLayout;
@@ -79,33 +88,50 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     m_pIconHLayout->setSpacing(0);
 
     //设置通知消息中的Icon，使用QToolButton
-    QToolButton* pIconToolButton = new QToolButton();
-    QIcon icon = QIcon::fromTheme(strIconPath);
-    pIconToolButton->setStyleSheet("QToolButton{border:none;border-style:none;padding:0px;background:transparent;}");
+    QLabel* pIconToolButton = new QLabel;
+
+    m_pAnimationBaseMapWidget->setAttribute(Qt::WA_TranslucentBackground);
+
     pIconToolButton->setFixedSize(24, 24);
-    pIconToolButton->setIconSize(QSize(24, 24));
-    pIconToolButton->setIcon(icon);
+    if (strIconPath.contains("file://")) {
+        int length = strIconPath.length();
+        strIconPath = strIconPath.mid(7, length);
+    }
+    QPixmap pixmap = QIcon::fromTheme(strIconPath, QIcon::fromTheme("application-x-desktop")).pixmap(QSize(24, 24));
+    PictureToWhite pictToWhite;
+    pIconToolButton->setPixmap(pictToWhite.drawSymbolicColoredPixmap(pixmap));
+    pIconToolButton->setAttribute(Qt::WA_TranslucentBackground);
+
+    //获取系统字体大小
+    QFont ft;
+    ft.setPointSize(14);
+    if(QGSettings::isSchemaInstalled(STYLE_FONT_SCHEMA))
+    {
+        const QByteArray styleID(STYLE_FONT_SCHEMA);
+        stylesettings = new QGSettings(styleID);
+        int fontSize = stylesettings->get("system-font-size").toInt();
+        ft.setPointSize(fontSize);
+    }
+    connect(stylesettings, SIGNAL(changed(const QString &)), this, SLOT(slotChangeFonts(const QString &)));
 
     //设置应用名标签，采用省略模式
     QLabel* pAppNameLabel = new QLabel();
     pAppNameLabel->setObjectName("AppName");
-    pAppNameLabel->setFixedWidth(84);
-    QFont font14;
-    font14.setPixelSize(14);
-    pAppNameLabel->setFont(font14);
+    pAppNameLabel->setAttribute(Qt::WA_TranslucentBackground);
+    pAppNameLabel->setFont(ft);
     QFontMetrics fontMetrics1(pAppNameLabel->font());
-
     QString formatAppName = fontMetrics1.elidedText(strAppName, Qt::ElideRight, pAppNameLabel->width());
     pAppNameLabel->setText(formatAppName);
 
     //设置通知消息中的弹簧，水平任意伸缩使应用名和时间分开
-    QSpacerItem* pHExpandSpacer = new QSpacerItem(400, 10, QSizePolicy::Expanding, QSizePolicy::Fixed);
+    QSpacerItem* pHExpandSpacer = new QSpacerItem(500, 10, QSizePolicy::Expanding, QSizePolicy::Fixed);
 
     //放置时间和收纳删除按钮的窗口
     m_pTimeLabelWidget = new QWidget;
-    m_pTimeLabelWidget->setFixedSize(146, 14);
+    m_pTimeLabelWidget->setFixedSize(146, 20);
     QHBoxLayout* pTimeLableHLayout = new QHBoxLayout();
 
+
     m_pStorageDeleteButtonWidget = new QWidget;
     m_pStorageDeleteButtonWidget->setFixedSize(146, 20);
     QHBoxLayout* pStorageDeleteButtonHLaout = new QHBoxLayout();
@@ -114,23 +140,20 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     m_pTimeLabel = new QLabel();
     m_pTimeLabel->setObjectName("pushtime");
     m_pTimeLabel->setText(tr("now"));
-    m_pTimeLabel->setStyleSheet("background-color:transparent;");
+    m_pTimeLabel->setAttribute(Qt::WA_TranslucentBackground);
 
     //收纳删除按钮图标的大小
     QSize normalIconSize(16, 16);
     QSize pressedIconSize(14, 14);
 
     //单独收纳按钮
-    if(false == m_bTakeInFlag)
-    {
+    if(false == m_bTakeInFlag){
         QString strIcon = ":/images/box-16-translucent.svg";
         QString strHoverIcon = ":/images/box-16.svg";
         QString strPressIcon = ":/images/box-14-translucent.svg";
         m_pSingleTakeinButton = new ButtonWidget(strIcon, strHoverIcon, strPressIcon, normalIconSize, pressedIconSize);
         connect(m_pSingleTakeinButton, SIGNAL(Sig_clicked()), this, SLOT(onTakeIn()));
-    }
-    else
-    {
+    } else {
         QString strIcon = ":/images/exitbox-16-translucent.svg";
         QString strHoverIcon = ":/images/exitbox-16.svg";
         QString strPressIcon = ":/images/exitbox-14-translucent.svg";
@@ -150,11 +173,11 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
 
     //设置标签布局
     pTimeLableHLayout->addWidget(m_pTimeLabel, 0, Qt::AlignRight);
-    pTimeLableHLayout->addItem(new QSpacerItem(26, 10 , QSizePolicy::Fixed, QSizePolicy::Fixed));
+    pTimeLableHLayout->addItem(new QSpacerItem(13, 10 , QSizePolicy::Fixed, QSizePolicy::Fixed));
     pTimeLableHLayout->setContentsMargins(0, 0, 0, 0);
     pTimeLableHLayout->setSpacing(0);
     m_pTimeLabelWidget->setLayout(pTimeLableHLayout);
-    m_pTimeLabelWidget->setStyleSheet("QWidget{background-color:transparent;}");
+    m_pTimeLabelWidget->setAttribute(Qt::WA_TranslucentBackground);
 
     //收纳和删除按钮布局
     pStorageDeleteButtonHLaout->addItem(new QSpacerItem(1, 10, QSizePolicy::Expanding, QSizePolicy::Fixed));
@@ -170,15 +193,16 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     m_pIconHLayout->addItem(new QSpacerItem(6, 10, QSizePolicy::Fixed, QSizePolicy::Fixed));
     m_pIconHLayout->addWidget(pAppNameLabel, 0, Qt::AlignLeft|Qt::AlignVCenter);
     m_pIconHLayout->addItem(pHExpandSpacer);
-    m_pIconHLayout->addWidget(m_pTimeLabelWidget);
-    m_pIconHLayout->addWidget(m_pStorageDeleteButtonWidget);
+    m_pIconHLayout->addWidget(m_pTimeLabelWidget, 0, Qt::AlignRight );
+    m_pIconHLayout->addWidget(m_pStorageDeleteButtonWidget, 0, Qt::AlignRight );
     m_pIconWidget->setLayout(m_pIconHLayout);
     pMainVLaout->addWidget(m_pIconWidget, 0);
-    m_pIconWidget->setStyleSheet("QWidget{background-color:rgba(255,0,0,0);}");
-    m_pStorageDeleteButtonWidget->setStyleSheet("QWidget{background-color:transparent;}");
+    m_pIconWidget->setAttribute(Qt::WA_TranslucentBackground);
+
+    m_pStorageDeleteButtonWidget->setAttribute(Qt::WA_TranslucentBackground);
+
     //内容部件,将主题正文以及剩余条数显示装入内容部件
     m_pContextWidget = new QWidget;
-//    m_pContextWidget->setStyleSheet("background-color:transparent;");
 
     //内容部件的垂直布局器
     QVBoxLayout* pVContextLayout = new QVBoxLayout();
@@ -188,10 +212,16 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     //设置通知消息中的主题，采用省略模式
     m_pSummaryLabel = new QLabel();
     m_pSummaryLabel->setFixedWidth(314);
-    m_pSummaryLabel->setStyleSheet("color:rgba(255,255,255,0.97);font-size:16px;background-color:transparent;line-height:26px;padding:0px;");
-    QFont font16;
-    font16.setPixelSize(16);
-    m_pSummaryLabel->setFont(font16);
+    m_pSummaryLabel->setAttribute(Qt::WA_TranslucentBackground);
+
+    //延时1秒设置字体
+    QTimer::singleShot(1, m_pSummaryLabel, [=]() {
+            QFont summaryFont = m_pSummaryLabel->font();
+            summaryFont.setPointSizeF(12);
+            summaryFont.setFamily("Noto Sans CJK SC");
+            summaryFont.setBold(true);
+            m_pSummaryLabel->setFont(summaryFont);
+        });
 
     QString formatSummary;
     formatSummary.append("<p style='line-height:26px'>").append(m_strSummary).append("</p>");
@@ -215,7 +245,8 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
         m_pBodyLabel->setFixedWidth(315);
         m_pBodyLabel->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
         m_pBodyLabel->adjustSize();
-        m_pBodyLabel->setStyleSheet("color:rgba(255,255,255,0.91);font-weight:400;font-size:14px;background-color:transparent;line-height:24px;padding:0px;");
+        m_pBodyLabel->setAttribute(Qt::WA_TranslucentBackground);
+
 
         QFontMetrics fontMetrics(m_pBodyLabel->font());
         int fontSize = fontMetrics.width(strLineHeight24Body);
@@ -234,64 +265,217 @@ SingleMsg::SingleMsg(AppMsg* pParent, QString strIconPath, QString strAppName, Q
     m_pShowLeftWidget = new QWidget;
     QVBoxLayout* pVShowLeftLayout = new QVBoxLayout();
     pVShowLeftLayout->setContentsMargins(0,6,0,14);
-
+    m_pShowLeftWidget->setAttribute(Qt::WA_TranslucentBackground);
     m_pShowLeftItemLabel = new QLabel;
     m_pShowLeftItemLabel->setObjectName("ShowLeftItem");
     m_pShowLeftItemLabel->setVisible(false);
     pVShowLeftLayout->addWidget(m_pShowLeftItemLabel, 0, Qt::AlignLeft);
     m_pShowLeftWidget->setLayout(pVShowLeftLayout);
     pVContextLayout->addWidget(m_pShowLeftWidget, 0, Qt::AlignLeft);
-
     m_pContextWidget->setLayout(pVContextLayout);
     pMainVLaout->addWidget(m_pContextWidget);
-    m_pContextWidget->setStyleSheet("QWidget{background-color:transparent;}");
+    m_pContextWidget->setAttribute(Qt::WA_TranslucentBackground);
     m_pSingleWidget->setLayout(pMainVLaout);
     m_pAppVLaout->addWidget(m_pSingleWidget);
     this->setLayout(m_pAppVLaout);
-
     m_pSetDeleDelayTimer = new QTimer(this);
-
-    setStyleSheet("background-color:rgba(255,255,255,0.12);");
     return;
 }
 
+void SingleMsg::initTimeFormatGsetting()
+{
+    const QByteArray id(CONTROL_CENTER_TIME_FORMAT_GSETTING);
+    QGSettings * fontSetting = new QGSettings(id);
+    QString timeFormat = fontSetting->get(CONTROL_TINE_FORMAT_GSETTING_VALUE).toString();
+    if (timeFormat == TIME_FORMAT) {
+        m_bTimeFormat = false;
+    } else {
+        m_bTimeFormat = true;
+    }
+    connect(fontSetting, &QGSettings::changed, this, [=](QString key) {
+        if (key == CONTROL_TINE_FORMAT_GSETTING_VALUE) {
+            QString value = fontSetting->get(CONTROL_TINE_FORMAT_GSETTING_VALUE).toString();
+            if (value == TIME_FORMAT) {
+                m_bTimeFormat = false;
+            } else {
+                m_bTimeFormat = true;
+            }
+        }
+    });
+}
+
+void SingleMsg::listenTimeZone()
+{
+    m_datetimeInterface = new QDBusInterface("org.freedesktop.timedate1",
+                                       "/org/freedesktop/timedate1",
+                                       "org.freedesktop.timedate1",
+                                       QDBusConnection::systemBus(), this);
+
+    QDBusConnection::systemBus().connect(QString("org.freedesktop.timedate1"),
+                                         QString("/org/freedesktop/timedate1"),
+                                         QString("org.freedesktop.DBus.Properties"),
+                                         QString("PropertiesChanged"), this, SLOT(listenTimeZoneSlots()));
+
+}
+
+void SingleMsg::listenTimeZoneSlots()
+{
+    QDateTime currentDateTime(QDateTime::currentDateTime());
+    m_uNotifyTime = currentDateTime.toTime_t() - m_uTimeDifference;
+    m_dateTime = QDateTime::fromTime_t(m_uNotifyTime);
+    updatePushTime();
+}
+
+void SingleMsg::slotChangeFonts(const QString &key)
+{
+    if(key != "systemFontSize")
+        return;
+    QFont ft;
+    int fontSize = 12;
+    ft.setPointSize(20);
+    if(QGSettings::isSchemaInstalled(STYLE_FONT_SCHEMA)){
+        fontSize = stylesettings->get("system-font-size").toInt();
+        ft.setPointSize(fontSize);
+    }
+    //主题显示
+    QString formatSummary;
+    formatSummary.append("<p style='line-height:26px'>").append(m_strSummary).append("</p>");
+    QFontMetrics fontMetrics(m_pSummaryLabel->font());
+    int nFontSize = fontMetrics.width(formatSummary);
+    QString strformatSummary = formatSummary;
+    if(nFontSize > (m_pSummaryLabel->width() + 239))
+    {
+        strformatSummary = fontMetrics.elidedText(formatSummary, Qt::ElideRight, m_pSummaryLabel->width() + 210);
+    }
+
+    QTimer::singleShot(1, m_pSummaryLabel, [=]() {
+            QFont summaryFont = m_pSummaryLabel->font();
+            summaryFont.setPointSizeF(fontSize+3);
+            summaryFont.setFamily("Noto Sans CJK SC");
+            summaryFont.setBold(true);
+            m_pSummaryLabel->setFont(summaryFont);
+        });
+
+    m_pSummaryLabel->setText(strformatSummary);
+
+    //正文显示
+    QString strLineHeight24Body;
+    strLineHeight24Body.append("<p style='line-height:24px'>").append(m_strBody).append("</p>");
+    QFontMetrics fontMetrics1(m_pBodyLabel->font());
+    QString formatBody = strLineHeight24Body;
+    if(fontSize > (m_pBodyLabel->width() + 209))
+    {
+        formatBody = fontMetrics1.elidedText(strLineHeight24Body, Qt::ElideRight, m_pBodyLabel->width() + 180);
+    }
+    m_pBodyLabel->setFont(ft);
+    m_pBodyLabel->setText(formatBody);
+
+}
+
+void SingleMsg::initGsettingValue()
+{
+    const QByteArray id(STYLE_FONT_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id))
+        m_pStyleGsetting = new QGSettings(id);
+}
+
+void SingleMsg::paintEvent(QPaintEvent *e)
+{
+
+    QPainter p(this);
+    QRect rect = this->rect();
+    rect.setWidth(rect.width() - 1);
+    rect.setHeight(rect.height() - 1);
+    p.setRenderHint(QPainter::Antialiasing);  // 反锯齿;
+    QString m_style = "ukui-light";
+
+    const QByteArray id(STYLE_FONT_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id))
+        m_style = m_pStyleGsetting->get("style-name").toString();
+
+    if (m_style=="ukui-light") {
+        p.setBrush(QBrush(QColor(255, 255, 255,255)));
+        p.setPen(Qt::transparent);
+        p.drawRoundedRect(rect,6,6);
+        switch (status) {
+          case NORMAL: {
+                p.setBrush(QBrush(QColor(255, 255, 255,0)));
+                p.setPen(Qt::NoPen);
+                p.drawRoundedRect(rect,6,6);
+                break;
+              }
+          case HOVER: {
+                p.setBrush(QBrush(QColor(255, 255, 255, 255)));
+                p.setPen(Qt::NoPen);
+                p.drawRoundedRect(rect,6,6);
+                this->update();
+                break;
+              }
+          case PRESS: {
+                p.setBrush(QBrush(QColor(255, 255, 255, 255)));
+                p.setPen(Qt::NoPen);
+                p.drawRoundedRect(rect,6,6);
+                this->update();
+                break;
+            }
+        }
+    } else {
+        p.setBrush(QBrush(QColor(255, 255, 255, 20)));
+        p.setPen(Qt::transparent);
+        p.drawRoundedRect(rect,6,6);
+        switch (status) {
+          case NORMAL: {
+                p.setBrush(QBrush(QColor(255, 255, 255, 0)));
+                p.setPen(Qt::NoPen);
+                p.drawRoundedRect(rect,6,6);
+                break;
+              }
+          case HOVER: {
+                p.setBrush(QBrush(QColor(255, 255, 255, 40)));
+                p.setPen(Qt::NoPen);
+                p.drawRoundedRect(rect,6,6);
+                  break;
+              }
+          case PRESS: {
+                p.setBrush(QBrush(QColor(255, 255, 255, 0)));
+                p.setPen(Qt::NoPen);
+                p.drawRoundedRect(rect,6,6);
+                break;
+             }
+        }
+    }
+
+    QWidget::paintEvent(e);
+
+}
 void SingleMsg::updatePushTime()
 {
     QDateTime currentDateTime(QDateTime::currentDateTime());
 
-    if(currentDateTime.toTime_t() < (m_uNotifyTime + 60))
-    {
+    m_uTimeDifference = currentDateTime.toTime_t() - m_uNotifyTime;
+
+    if (currentDateTime.toTime_t() < (m_uNotifyTime + 60)) {
         return;
     }
-
     QString strPushDate;
-    if(m_dateTime.date() == currentDateTime.date())
-    {
-        if(true == m_bTimeFormat)
-        {
+    if (m_dateTime.date() == currentDateTime.date()) {
+        if(true == m_bTimeFormat) {
             strPushDate = m_dateTime.toString("hh:mm");                     //24小时制
-        }
-        else
-        {
+        } else {
             strPushDate = m_dateTime.toString("AP h:mm");                   //12小时制
         }
         m_pTimeLabel->setText(strPushDate);
         return;
     }
 
-    if(1 == (currentDateTime.date().toJulianDay() - m_dateTime.date().toJulianDay()))
-    {
+    if (1 == (currentDateTime.date().toJulianDay() - m_dateTime.date().toJulianDay())) {
         strPushDate = tr("Yesterday ");
-        if(true == m_bTimeFormat)
-        {
+        if(true == m_bTimeFormat) {
             strPushDate = strPushDate + m_dateTime.toString("hh:mm");       //24小时制
-        }
-        else
-        {
+        } else {
             strPushDate = strPushDate + m_dateTime.toString("AP h:mm");     //12小时制
         }
         m_pTimeLabel->setText(strPushDate);
-
         return;
     }
 
@@ -328,7 +512,7 @@ void SingleMsg::setBodyLabelWordWrap(bool bFlag)
     m_pBodyLabel->setWordWrap(bFlag);
     QFont font14;
     font14.setPixelSize(14);
-    m_pBodyLabel->setFont(font14);
+//    m_pBodyLabel->setFont(font14);
     QFontMetrics fontMetrics(m_pBodyLabel->font());
     QString strLineHeight24Body;
     strLineHeight24Body.append("<p style='line-height:24px'>").append(m_strBody).append("</p>");
@@ -337,11 +521,27 @@ void SingleMsg::setBodyLabelWordWrap(bool bFlag)
 
     if(true == bFlag)
     {
-        //如果展开,就超过四行末尾显示省略号
-        //if(fontSize > (m_pBodyLabel->width() * 4 + 181))
-        {
-            formatBody = fontMetrics.elidedText(strLineHeight24Body, Qt::ElideRight, m_pBodyLabel->width() * 4 + 152);
+        // //如果展开,就超过四行末尾显示省略号
+
+        // {
+        //     formatBody = fontMetrics.elidedText(strLineHeight24Body, Qt::ElideRight, m_pBodyLabel->width() * 4 + 152);
+        // }
+                //处理要显示的字符串，在换行处加入空格,防止因为QLabel换行机制导致显示不完整
+        QString strDisplay;
+        uint j=1;
+        int labelWidth = m_pBodyLabel->width();
+        for(int i=0;i<m_strBody.length();i++){
+            strDisplay += QString(m_strBody.at(i));
+            uint fontSize = fontMetrics.width(strDisplay);
+            if(fontSize > (j*(labelWidth-8))){
+                strDisplay+=" ";
+                j++;
+            }
         }
+        QString strTmp;
+        strTmp.append("<p style='line-height:24px'>").append(strDisplay).append("</p>");
+        //如果展开,超过四行末尾显示省略号
+        formatBody = fontMetrics.elidedText(strTmp, Qt::ElideRight, m_pBodyLabel->width() * 4 + 152);
     }
     else
     {
@@ -362,7 +562,7 @@ void SingleMsg::setLeftItem(int nShowLeftCount)
     m_nShowLeftCount = nShowLeftCount;
     QString strShowLeft = tr("In addition ") + QString::number(nShowLeftCount) + tr(" notification");
     m_pShowLeftItemLabel->setText(strShowLeft);
-    m_pShowLeftItemLabel->setStyleSheet("color:rgba(255,255,255,0.35);font-weight:400;font-size:14px;font-weight:400;background-color:transparent;line-height:24px;padding:0px;");
+    m_pShowLeftItemLabel->setAttribute(Qt::WA_TranslucentBackground);
 
     //当剩余条数大于0, 且是折叠状态则显示剩余标签
     if((true == m_bFold) && (m_nShowLeftCount > 0))
@@ -390,23 +590,17 @@ void SingleMsg::setSingleMsgContentsMargins(int left, int top, int right, int bo
 void SingleMsg::enterEvent(QEvent *event)
 {
     Q_UNUSED(event);
-
-    if((true == m_bMain) && (false == m_bFold) && (m_nShowLeftCount > 0))
-    {
-        setStyleSheet("background-color:rgba(255,255,255,0.28);");
-    }
-    else
-    {
-        setStyleSheet("background-color:rgba(255,255,255,0.2);");
-    }
-
+    status = HOVER;
     m_pStorageDeleteButtonWidget->show();
     m_pTimeLabelWidget->hide();
     m_pIconHLayout->setContentsMargins(10, 11, 0, 0);
+
     if((true == m_bMain) && (true == m_bFold) && (m_nShowLeftCount > 0))
     {
         emit Sig_onMainEnter();
     }
+    this->update();
+    QTimer::singleShot(50,[this]{this->update();});
 
     return;
 }
@@ -415,14 +609,7 @@ void SingleMsg::leaveEvent(QEvent *event)
 {
     Q_UNUSED(event);
 
-    if((true == m_bMain) && (false == m_bFold) && (m_nShowLeftCount > 0))
-    {
-        setStyleSheet("background-color:rgba(255,255,255,0.2);");
-    }
-    else
-    {
-        setStyleSheet("background-color:rgba(255,255,255,0.12);");
-    }
+    status =NORMAL;
     m_pTimeLabelWidget->show();
     m_pStorageDeleteButtonWidget->hide();
     m_pIconHLayout->setContentsMargins(10, 11, 0, 0);
@@ -430,13 +617,14 @@ void SingleMsg::leaveEvent(QEvent *event)
     {
         emit Sig_onMainLeave();
     }
-
+    this->update();
     return;
 }
 
 //鼠标点击事件
 void SingleMsg::mousePressEvent(QMouseEvent *event)
 {
+    status =PRESS;
     if (event->buttons() == Qt::LeftButton)
     {
         if(true == m_bFold)
@@ -450,15 +638,6 @@ void SingleMsg::mousePressEvent(QMouseEvent *event)
             setBodyLabelWordWrap(false);
         }
 
-        if((true == m_bMain) && (false == m_bFold) && (m_nShowLeftCount > 0))
-        {
-            setStyleSheet("background-color:rgba(255,255,255,0.28);");
-        }
-        else
-        {
-            setStyleSheet("background-color:rgba(255,255,255,0.2);");
-        }
-
         //当消息为主窗口时,发送折叠信息给App
         if(true == m_bMain)
         {
@@ -476,25 +655,11 @@ void SingleMsg::mousePressEvent(QMouseEvent *event)
 
             emit Sig_setAppFoldFlag(m_bFold);
         }
+        this->update();
     }
     return;
 }
 
-//void SingleMsg::resizeEvent(QResizeEvent *event)
-//{
-//    QDateTime currentDateTime(QDateTime::currentDateTime());
-//    QString strCurrentTime = currentDateTime.toString("hh:mm:ss.zzz");
-
-//    if(true == m_bMain)
-//    {
-//        qDebug()<<strCurrentTime <<"SingleMsg::resizeEvent"<<this <<this->height() <<m_pSingleWidget->height() <<m_pIconWidget->height() <<m_pContextWidget->height() <<m_pShowLeftWidget->height();
-//    }
-//    else
-//    {
-//        qDebug()<<strCurrentTime <<"SingleMsg::resizeEvent11"<<this <<this->height() <<m_pSingleWidget->height() <<m_pIconWidget->height() <<m_pContextWidget->height() <<m_pShowLeftWidget->height();
-//    }
-//}
-
 void SingleMsg::mainMsgSetFold()
 {
     //当消息为主窗口时,由主消息设置折叠
@@ -511,7 +676,7 @@ void SingleMsg::mainMsgSetFold()
             m_pShowLeftItemLabel->setVisible(true);
         }
         emit Sig_setAppFoldFlag(true);
-        setStyleSheet("background-color:rgba(255,255,255,0.12);");  //对于主消息手动补一下背景色
+
     }
 }
 
@@ -521,12 +686,9 @@ void SingleMsg::startAnimationUnfold()
     int width = this->width();
     int height = this->height();
 
-    if(true == m_strBody.isEmpty())
-    {
+    if(true == m_strBody.isEmpty()) {
         height = 87;
-    }
-    else
-    {
+    } else {
         height = 111;
     }
 
@@ -670,9 +832,7 @@ void SingleMsg::updateUnfoldMove(const QVariant &value)
 
     QDateTime currentDateTime(QDateTime::currentDateTime());
     QString strCurrentTime = currentDateTime.toString("hh:mm:ss.zzz");
-//    QString LogInfo;
-//    LogInfo.sprintf("%p", QThread::currentThread());
-    qDebug()<<strCurrentTime <<"SingleMsg::updateUnfoldMove"<<this<<" x1=" <<x1<<" y1="<<y1<<" x2=" <<x2<<" y2="<<y2;
+//    qDebug()<<strCurrentTime <<"SingleMsg::updateUnfoldMove"<<this<<" x1=" <<x1<<" y1="<<y1<<" x2=" <<x2<<" y2="<<y2;
 
 
     //首先将填充控件的高度不断增加直至6
