@@ -24,41 +24,48 @@
 #include <stdio.h>
 #include <QtDBus>
 #include <QGuiApplication>
+#include "xeventmonitor.h"
 #include "customstyle.h"
 
 double tranSparency = 0.7;
 
 Widget::Widget(QWidget *parent) : QWidget (parent)
 {
-    m_pTranslator = new QTranslator;
-    if (m_pTranslator->load(QLocale(), QLatin1String("ukui-sidebar"), QLatin1String("_"), QLatin1String("/usr/share/ukui-sidebar")))
-        QApplication::installTranslator(m_pTranslator);
-    else
-        qDebug() << "cannot load translator " << QLocale::system().name() << ".qm!";
-    m_bShowFlag = false;
-    m_bClipboardFlag = true;
+    //先仅注册托盘图标
+    initTrayIcon();
+//    startBackgroundFunction();
+}
 
-    /* 链接任务栏Dbus接口，获取任务栏高度和位置 */
-    m_pServiceInterface = new QDBusInterface(PANEL_DBUS_SERVICE, PANEL_DBUS_PATH, PANEL_DBUS_INTERFACE, QDBusConnection::sessionBus());
-    m_pServiceInterface->setTimeout(2147483647);
+Widget::~Widget()
+{
+    XEventMonitor::instance()->quit();
+}
 
-    /* 链接任务栏Dbus接口，获取任务栏点击信号 */
-    QDBusConnection::sessionBus().connect(QString(), QString("/taskbar/click"), \
-                                          "com.ukui.panel.plugins.taskbar", "sendToUkuiDEApp", this, SLOT(ClickPanelHideSidebarSlots(void)));
+void Widget::initTrayIcon()
+{
+    createSystray();
+    setIcon(QIcon::fromTheme("kylin-tool-box", QIcon(TRAY_ICON)));
+}
 
-    /* 链接任务栏dgsetting接口 */
-    if(QGSettings::isSchemaInstalled(UKUI_PANEL_SETTING))
-        m_pPanelSetting = new QGSettings(UKUI_PANEL_SETTING);
+void Widget::startBackgroundFunction()
+{
+    /* 国际化 */
+    initTranslation();
 
-    /* 监听屏幕分辨率是否变化 主频是否有变化 初始化屏幕宽高 和主屏起始X坐标值 */
-    m_pDeskWgt = QApplication::desktop();
-//    connect(m_pDeskWgt, SIGNAL(resized(int)), this, SLOT(onResolutionChanged(int)));
-    connect(QApplication::primaryScreen(), &QScreen::geometryChanged, this, &Widget::onResolutionChanged);
-    connect(m_pDeskWgt, &QDesktopWidget::primaryScreenChanged, this, &Widget::primaryScreenChangedSLot);
-    connect(m_pDeskWgt, &QDesktopWidget::screenCountChanged, this, &Widget::screenCountChangedSlots);
+    /* 初始化与任务栏交互的dbus和gsetting */
+    initPanelDbusGsetting();
 
-    InitializeHomeScreenGeometry();  /* 初始化主屏的X坐标 */
-    GetsAvailableAreaScreen();       /* 获取屏幕可用高度区域 */
+    /* 初始化屏幕 */
+    initDesktopPrimary();
+
+    /* 初始化主屏的X坐标 */
+    InitializeHomeScreenGeometry();
+
+    /* 获取屏幕可用高度区域 */
+//    GetsAvailableAreaScreen();
+
+    /* 初始化动画 */
+    initAimation();
 
     /* 主界面显示 */
     m_pMainQVBoxLayout = new QVBoxLayout;
@@ -71,49 +78,96 @@ Widget::Widget(QWidget *parent) : QWidget (parent)
 
     /* 加载通知中心插件 */
     if (false == loadNotificationPlugin())
-        qDebug() << "通知中心插件加载失败";
+        qDebug() << "Notification center plug-in failed to load";
 
-    /* 加载剪贴板插件, 将剪贴板插件加入到sidebarPluginsWidgets的GroupBox中 */
+    /* 加载剪贴板插件 */
     if (ListenClipboardSignal())
-        qDebug() << "剪贴板插件加载失败";
+        qDebug() << "The clipboard plug-in failed to load";
 
     this->setLayout(m_pMainQVBoxLayout);
 
     /* 系统托盘栏显示 */
     createAction();
-    createSystray();
-    setIcon(QIcon::fromTheme("kylin-tool-box", QIcon(TRAY_ICON)));
 
     /* 安装事件过滤器 */
     installEventFilter(this);
 
-    m_pAnimationShowSidebarWidget = new QPropertyAnimation(this, "geometry");
-    m_pAnimationHideSidebarWidget = new QPropertyAnimation(this, "geometry");
-
-    connect(m_pAnimationHideSidebarWidget, &QPropertyAnimation::finished, this, &Widget::hideAnimationFinish);
-    connect(m_pAnimationShowSidebarWidget, &QPropertyAnimation::valueChanged, this, &Widget::showAnimationAction);
-    connect(m_pAnimationShowSidebarWidget, &QPropertyAnimation::finished, this, &Widget::showAnimationFinish);
-
-    /* 将托盘栏图标和widget联系起来 */
-    connect(trayIcon, &QSystemTrayIcon::activated, this, &Widget::iconActivated);
-    trayIcon->setVisible(true);
+    /* 监听gsetting，修改所有窗口的字体 */
+    setAllWidgetFont();
 
     if (QGSettings::isSchemaInstalled(UKUI_TRANSPARENCY_SETTING)) {
-        qDebug() << "分配gsetting值";
         m_pTransparency = new QGSettings(UKUI_TRANSPARENCY_SETTING);
-//        connect(m_pTransparency, &QGSettings::changed, this, &sidebarPluginsWidgets::getTransparencyValue);
     }
 
+    //快捷参数
+    if (QApplication::arguments().length() > 1) {
+        bootOptionsFilter(QApplication::arguments().at(1));
+    }
     this->setWindowFlags(Qt::FramelessWindowHint | Qt::X11BypassWindowManagerHint);
+    /* 监听键盘事件 */
+    XEventMonitor::instance()->start();
+    connect(XEventMonitor::instance(), SIGNAL(keyRelease(QString)),
+           this,SLOT(XkbEventsRelease(QString)));
+    connect(XEventMonitor::instance(), SIGNAL(keyPress(QString)),
+           this,SLOT(XkbEventsPress(QString)));
     qInfo() << "---------------------------主界面加载完毕---------------------------";
-
-    m_pUpdateSmallPluginsWidget = new QTimer();
-    connect(m_pUpdateSmallPluginsWidget, &QTimer::timeout, this, &Widget::updateSmallPluginsClipboardWidget);
 }
 
-Widget::~Widget()
+void Widget::XkbEventsPress(const QString &keycode)
 {
+    QString KeyName;
+    if (keycode.length() >= 8) {
+        KeyName = keycode.left(8);
+    }
 
+    if (KeyName.compare("Super_L+")==0) {
+        m_winFlag = true;
+    }
+
+    if (m_winFlag && keycode == "Super_L") {
+        m_winFlag = false;
+        return;
+    }
+
+}
+
+void Widget::XkbEventsRelease(const QString &keycode)
+{
+    QString KeyName;
+    static bool winFlag=false;
+    if (keycode.length() >= 8) {
+        KeyName = keycode.left(8);
+    }
+
+    if (KeyName.compare("Super_L+")==0) {
+        winFlag = true;
+    }
+
+    if (winFlag && keycode == "Super_L") {
+        winFlag = false;
+        return;
+    } else if (m_winFlag && keycode == "Super_L")
+        return;
+
+    if (keycode == "Super_L+a") {
+        if(m_bShowFlag) {
+            mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
+            hideAnimation();
+            //this->hide();
+        } else {
+            mostGrandWidget::getInstancemostGrandWidget()->hide();
+            MostGrandWidgetCoordinates();
+            mostGrandWidget::getInstancemostGrandWidget()->show();
+            showAnimation();
+            m_bShowFlag = true;
+            setIcon(QIcon::fromTheme("kylin-tool-box", QIcon(TRAY_ICON)));
+            /*
+            this->show();
+            this->raise();
+            this->activateWindow();
+            */
+        }
+    }
 }
 
 //加载通知中心插件
@@ -131,17 +185,15 @@ bool Widget::loadNotificationPlugin()
     QPluginLoader pluginLoader(pluginsDir.absoluteFilePath("libnotification_plugin.so"));
 
     m_pNotificationPluginObject = pluginLoader.instance();
-    if(nullptr == m_pNotificationPluginObject) {
+    if (nullptr == m_pNotificationPluginObject) {
         return false;
     }
 
     NotificationInterface* pNotificationPluginObject = qobject_cast<NotificationInterface*>(m_pNotificationPluginObject);
-    if(nullptr == pNotificationPluginObject) {
+    if (nullptr == pNotificationPluginObject) {
         return false;
     }
-    QWidget *widget = pNotificationPluginObject->centerWidget();
-    QString sheet = QString("QWidget{background-color:rgba(19,19,20,%1);}").arg(tranSparency);
-    widget->setStyleSheet(sheet);
+
     connect(m_pNotificationPluginObject, SIGNAL(Sig_onNewNotification()), this, SLOT(onNewNotification()));
     m_pMainQVBoxLayout->addWidget(pNotificationPluginObject->centerWidget(), 1);
     return true;
@@ -197,6 +249,11 @@ void Widget::createAction()
 
     OpenSetUp = new QAction(QIcon::fromTheme("application-menu", QIcon(SETTING_ICON)), QObject::tr("Set up notification center"), this);
     connect(OpenSetUp, &QAction::triggered, this, &Widget::OpenControlCenterSettings);
+
+    trayIconMenu->addAction(Open);
+    trayIconMenu->addAction(OpenSetUp);
+
+    connect(trayIcon, &QSystemTrayIcon::activated, this, &Widget::iconActivated);
 }
 
 //添加动作和创建 systray实例
@@ -208,18 +265,27 @@ void Widget::createSystray()
         qWarning() << "分配空间trayIconMenu失败";
         return ;
     }
-    trayIconMenu->addAction(Open);
-    trayIconMenu->addAction(OpenSetUp);
 
     trayIcon = new QSystemTrayIcon(this);
-
     if (nullptr == trayIcon) {
         qWarning()<< "分配空间trayIcon失败";
         return ;
     }
+    connect(trayIcon, &QSystemTrayIcon::activated, this, &Widget::clickTrayFunction);
+
+    trayIcon->setVisible(true);
     trayIcon->setContextMenu(trayIconMenu);
 }
 
+void Widget::clickTrayFunction(QSystemTrayIcon::ActivationReason reason)
+{
+    if (!oneShotBool){
+        disconnect(trayIcon, &QSystemTrayIcon::activated, this, &Widget::clickTrayFunction);
+        emit startRun(reason);
+        oneShotBool = true;
+    }
+}
+
 //设置托盘栏的图标
 void Widget::setIcon(QIcon icon)
 {
@@ -237,7 +303,6 @@ void Widget::iconActivated(QSystemTrayIcon::ActivationReason reason)
             tranSparency = m_pTransparency->get("transparency").toDouble();
         }
     }
-    qDebug() << "获取的透明度为:" << tranSparency;
     switch (reason) {
         case QSystemTrayIcon::Trigger: {
             if (m_bShowFlag) {
@@ -265,6 +330,33 @@ void Widget::iconActivated(QSystemTrayIcon::ActivationReason reason)
     }
 }
 
+/* 初始化屏幕分辨率 */
+void Widget::initDesktopPrimary()
+{
+    /* 监听屏幕分辨率是否变化 主频是否有变化 初始化屏幕宽高 和主屏起始X坐标值 */
+    m_pDeskWgt = QApplication::desktop();
+    connect(QApplication::primaryScreen(), &QScreen::geometryChanged, this, &Widget::onResolutionChanged);
+    connect(QApplication::primaryScreen(), &QScreen::virtualGeometryChanged, this, &Widget::onResolutionChanged);
+    connect(m_pDeskWgt, &QDesktopWidget::primaryScreenChanged, this, &Widget::primaryScreenChangedSLot);
+    connect(m_pDeskWgt, &QDesktopWidget::screenCountChanged, this, &Widget::screenCountChangedSlots);
+
+}
+
+void Widget::initPanelDbusGsetting()
+{
+    /* 链接任务栏Dbus接口，获取任务栏高度和位置 */
+    m_pServiceInterface = new QDBusInterface(PANEL_DBUS_SERVICE, PANEL_DBUS_PATH, PANEL_DBUS_INTERFACE, QDBusConnection::sessionBus());
+    m_pServiceInterface->setTimeout(2147483647);
+
+    /* 链接任务栏Dbus接口，获取任务栏点击信号 */
+    QDBusConnection::sessionBus().connect(QString(), QString("/taskbar/click"), \
+                                          "com.ukui.panel.plugins.taskbar", "sendToUkuiDEApp", this, SLOT(ClickPanelHideSidebarSlots(void)));
+
+    /* 链接任务栏dgsetting接口 */
+    if(QGSettings::isSchemaInstalled(UKUI_PANEL_SETTING))
+        m_pPanelSetting = new QGSettings(UKUI_PANEL_SETTING);
+}
+
 //链接任务栏dbus获取高度的接口
 int Widget::connectTaskBarDbus()
 {
@@ -282,6 +374,63 @@ int Widget::connectTaskBarDbus()
     return panelHeight;
 }
 
+// 初始化华为990dbus接口
+bool Widget::initHuaWeiDbus()
+{
+    if(!m_pDbusXrandInter) {
+        m_pDbusXrandInter = new QDBusInterface(DBUS_NAME,
+                                             DBUS_PATH,
+                                             DBUS_INTERFACE,
+                                             QDBusConnection::sessionBus());
+
+        connect(m_pDbusXrandInter, SIGNAL(screenPrimaryChanged(int,int,int,int)),
+                this, SLOT(priScreenChanged(int,int,int,int)));
+    }
+    m_nScreen_x = getScreenGeometry("x");
+    m_nScreen_y = getScreenGeometry("y");
+    m_nScreenWidth = getScreenGeometry("width");
+    m_nScreenHeight = getScreenGeometry("height");
+    qDebug() << "HW--->偏移的x坐标------------------------------>" << m_nScreen_x;
+    qDebug() << "HW--->偏移的Y坐标------------------------------>" << m_nScreen_y;
+    if (m_nScreenWidth == 0 || m_nScreenHeight == 0) {
+        qDebug() << "无dbus可用接口HW";
+        return false;
+    } else {
+        qDebug() << "有dbus可用接口HW";
+        return true;
+    }
+}
+
+/* get primary screen changed */
+void Widget::priScreenChanged(int x, int y, int width, int height)
+{
+    qDebug("primary screen  changed, geometry is  x=%d, y=%d, windth=%d, height=%d", x, y, width, height);
+    m_nScreen_x = x;
+    m_nScreen_y = y;
+    m_nScreenWidth = width;
+    m_nScreenHeight = height;
+}
+
+int Widget::getScreenGeometry(QString methodName)
+{
+    int res = 0;
+    QDBusMessage message = QDBusMessage::createMethodCall(DBUS_NAME,
+                               DBUS_PATH,
+                               DBUS_INTERFACE,
+                               methodName);
+    QDBusMessage response = QDBusConnection::sessionBus().call(message);
+    if (response.type() == QDBusMessage::ReplyMessage) {
+        if(response.arguments().isEmpty() == false) {
+            int value = response.arguments().takeFirst().toInt();
+            res = value;
+            qDebug() << value;
+        }
+    } else {
+        qDebug()<<methodName<<"called failed";
+    }
+    return res;
+}
+
 //获取任务栏状态位置下上左右
 int Widget::getPanelSite()
 {
@@ -310,7 +459,7 @@ void Widget::GetsAvailableAreaScreen()
         m_nScreenHeight = DeskSize.height();                    //桌面分辨率的高
     } else {
         //如果取到任务栏的高度,则取屏幕分辨率的高度
-        QRect screenRect = m_pDeskWgt->screenGeometry();
+        QRect screenRect = QGuiApplication::primaryScreen()->geometry();
         m_nScreenWidth = screenRect.width();
         m_nScreenHeight = screenRect.height();
     }
@@ -332,11 +481,30 @@ int Widget::setClipBoardWidgetScaleFactor()
     }
 }
 
+void Widget::initTranslation()
+{
+    m_pTranslator = new QTranslator;
+    if (m_pTranslator->load(QLocale(), QLatin1String("ukui-sidebar"), QLatin1String("_"), QLatin1String("/usr/share/ukui-sidebar")))
+        QApplication::installTranslator(m_pTranslator);
+    else
+        qDebug() << "cannot load translator " << QLocale::system().name() << ".qm!";
+}
+
+void Widget::initAimation()
+{
+    m_pAnimationShowSidebarWidget = new QPropertyAnimation(this, "geometry");
+    m_pAnimationHideSidebarWidget = new QPropertyAnimation(this, "geometry");
+    m_pAnimationShowSidebarWidget->start();
+    mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
+    connect(m_pAnimationHideSidebarWidget, &QPropertyAnimation::finished, this, &Widget::hideAnimationFinish);
+    connect(m_pAnimationShowSidebarWidget, &QPropertyAnimation::valueChanged, this, &Widget::showAnimationAction);
+}
+
 //动画展开
 void Widget::showAnimation()
 {
     NotificationInterface* pNotificationPluginObject = qobject_cast<NotificationInterface*>(m_pNotificationPluginObject);
-    if (nullptr != pNotificationPluginObject && false == m_bfinish)
+    if (nullptr != pNotificationPluginObject)
         pNotificationPluginObject->showNotification();       //当动画展开时给插件一个通知
 
     int  AnimaStartSideBarSite[4];                           //侧边栏动画开始位置
@@ -423,17 +591,7 @@ void Widget::showAnimationAction(const QVariant &value)
     }
 }
 
-void Widget::showAnimationFinish()
-{
-    if (m_bfinish) {
-        mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
-        hideAnimation();
-        m_bfinish = false;
-    }
-    return;
-}
-
-/* 获取Getting值 */
+/* 获取Getting透明度值 */
 void sidebarPluginsWidgets::getTransparencyValue(const QString key)
 {
     if (key == "transparency") {
@@ -531,9 +689,8 @@ void Widget::onResolutionChanged(const QRect argc)
 {
     Q_UNUSED(argc);
     qDebug() << "屏幕分辨率发生变化";
-    GetsAvailableAreaScreen();                               //获取屏幕可用高度区域
-    ModifyScreenNeeds();                                     //修改屏幕分辨率或者主屏需要做的事情
     InitializeHomeScreenGeometry();
+    ModifyScreenNeeds();                                     //修改屏幕分辨率或者主屏需要做的事情
     return;
 }
 
@@ -541,9 +698,8 @@ void Widget::onResolutionChanged(const QRect argc)
 void Widget::primaryScreenChangedSLot()
 {
     qDebug() << "主屏发生变化";
-    GetsAvailableAreaScreen();
-    ModifyScreenNeeds();
     InitializeHomeScreenGeometry();
+    ModifyScreenNeeds();
     return;
 }
 
@@ -552,20 +708,19 @@ void Widget::screenCountChangedSlots(int count)
 {
     Q_UNUSED(count);
     qDebug() << "屏幕数量发生变化";
-    GetsAvailableAreaScreen();
-    ModifyScreenNeeds();
     InitializeHomeScreenGeometry();
+    ModifyScreenNeeds();
     return;
 }
 
-/* 接受剪贴板信号，将boll值m_bClipboardFlag置为false; */
+/* 接受剪贴板信号，将bool值m_bClipboardFlag置为false; */
 void Widget::ClipboardShowSlots()
 {
     m_bClipboardFlag = false;
     return;
 }
 
-/* 接受剪贴板信号，将boll值m_bClipboardFlag置为true; */
+/* 接受剪贴板信号，将bool值m_bClipboardFlag置为true; */
 void Widget::ClipboardHideSlots()
 {
     m_bClipboardFlag = true;
@@ -575,8 +730,10 @@ void Widget::ClipboardHideSlots()
 /* 接受任务栏点击信号，当任务栏点击左键时，关闭任务栏 */
 void Widget::ClickPanelHideSidebarSlots()
 {
-    mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
-    hideAnimation();
+    if (m_bClipboardFlag) {
+        mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
+        hideAnimation();
+    }
     return;
 }
 
@@ -609,21 +766,60 @@ void Widget::ModifyScreenNeeds()
     return;
 }
 
+void Widget::initOsSiteXY()
+{
+    if (QGuiApplication::primaryScreen()) {
+        m_nScreen_x = QGuiApplication::primaryScreen()->geometry().x();
+        m_nScreen_y = QGuiApplication::primaryScreen()->geometry().y();
+    } else {
+        QList<QScreen*> screen = QGuiApplication::screens();
+        int count = m_pDeskWgt->screenCount();
+        if (count > 1) {
+            m_nScreen_x = screen[0]->geometry().x();
+            m_nScreen_y = screen[0]->geometry().y();
+
+        } else {
+            m_nScreen_x = 0;
+            m_nScreen_y = 0;
+        }
+    }
+}
+
 /* 初始化主屏的X坐标 */
 void Widget::InitializeHomeScreenGeometry()
 {
-    QList<QScreen*> screen = QGuiApplication::screens();
-    int count = m_pDeskWgt->screenCount();
-    if (count > 1) {
-        m_nScreen_x = screen[0]->geometry().x();
-        m_nScreen_y = screen[0]->geometry().y();
-
-    } else {
-        m_nScreen_x = 0;
-        m_nScreen_y = 0;
+    QString ArchDiff = qgetenv(ENV_XDG_SESSION_TYPE);
+    if (ArchDiff == ENV_WAYLAND) {
+        if (!initHuaWeiDbus()) {
+            initOsSiteXY();
+            GetsAvailableAreaScreen();
+            qDebug() << "HW--->偏移的x坐标，初始化坐标错误------------------------------>" << m_nScreen_x;
+            qDebug() << "HW--->偏移的Y坐标，初始化坐标错误------------------------------>" << m_nScreen_y;
+            return;
+        }
+    } else if (ArchDiff == ENV_X11) {
+        initOsSiteXY();
+        GetsAvailableAreaScreen();
+        qDebug() << "偏移的x坐标------------------------------>" << m_nScreen_x;
+        qDebug() << "偏移的Y坐标------------------------------>" << m_nScreen_y;
     }
-    qDebug() << "偏移的x坐标" << m_nScreen_x;
-    qDebug() << "偏移的Y坐标" << m_nScreen_y;
+    return;
+}
+
+/* 监听gsetting，修改所有的字体 */
+void Widget::setAllWidgetFont()
+{
+    const QByteArray id("org.ukui.style");
+        QGSettings * fontSetting = new QGSettings(id);
+        connect(fontSetting, &QGSettings::changed,[=](QString key){
+            if ("systemFont" == key || "systemFontSize" ==key) {
+                QFont font = this->font();
+                for (auto widget : qApp->allWidgets()) {
+                    widget->setFont(font);
+                }
+                emit sidebarPluginsWidgets::getInstancePluinsWidgets()->FontModifyComplete();
+            }
+        });
 }
 
 /* 根据任务栏位置调整侧边栏位置 */
@@ -634,7 +830,6 @@ void Widget::MostGrandWidgetCoordinates()
             {
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetSize(400, m_nScreenHeight - connectTaskBarDbus());
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(m_nScreen_x + m_nScreenWidth - 400, m_nScreen_y);
-                qDebug() << "m_nScreen_x + m_nScreenWidth - 400-->" << m_nScreen_x + m_nScreenWidth - 400 << "&&" << m_nScreen_x << "&&" << m_nScreenWidth;
                 emit m_pSidebarSignal->ClipboardPreviewSignal(400, m_nScreenHeight, m_nScreen_x + m_nScreenWidth - 400, m_nScreen_y, connectTaskBarDbus());
             }
             break;
@@ -650,8 +845,6 @@ void Widget::MostGrandWidgetCoordinates()
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetSize(400, m_nScreenHeight);
                 mostGrandWidget::getInstancemostGrandWidget()->setMostGrandwidgetCoordinates(m_nScreen_x + connectTaskBarDbus(), m_nScreen_y);
                 emit m_pSidebarSignal->ClipboardPreviewSignal(400, m_nScreenHeight, m_nScreen_x + connectTaskBarDbus() + 400 + 260, m_nScreen_y, 0);
-                qDebug() << "当前 m_nScreen_x + m_nScreenWidth + connectTaskBarDbus()--》" << m_nScreen_x + connectTaskBarDbus() << "m_nScreen_y ----> "  << m_nScreen_y;
-
             }
             break;
         case Widget::PanelRight:
@@ -679,27 +872,35 @@ void Widget::onNewNotification()
 void Widget::updateSmallPluginsClipboardWidget()
 {
     ModifyScreenNeeds();
-    m_pUpdateSmallPluginsWidget->stop();
+}
+
+/* 过滤终端命令 */
+void Widget::bootOptionsFilter(QString opt){
+    if (opt == "-s" || opt == "-show" && m_bShowFlag == false) {
+        mostGrandWidget::getInstancemostGrandWidget()->hide();
+        MostGrandWidgetCoordinates();
+        mostGrandWidget::getInstancemostGrandWidget()->show();
+        showAnimation();
+        m_bShowFlag = true;
+        setIcon(QIcon::fromTheme("kylin-tool-box", QIcon(TRAY_ICON)));
+    }
 }
 
 /* 事件过滤器 */
 bool Widget::eventFilter(QObject *obj, QEvent *event)
 {
     if (obj == this) {
-        if (event->type() == QEvent::WindowDeactivate && true == m_bShowFlag && true == m_bClipboardFlag) {
-            qDebug() << "Widget::eventFilter 消失";
+        if (event->type() == QEvent::WindowDeactivate \
+                && true == m_bShowFlag && true == m_bClipboardFlag) {
             mostGrandWidget::getInstancemostGrandWidget()->topLevelWidget()->setProperty("blurRegion", QRegion(QRect(1, 1, 1, 1)));
             hideAnimation();
             m_bShowFlag = false;
             return true;
         } else if (event->type() == QEvent::StyleChange) {
-            m_pUpdateSmallPluginsWidget->start(200);
             sidebarPluginsWidgets::getInstancePluinsWidgets()->setButtonFont();
             return true;
         }
     }
-
-
     if (!isActiveWindow() && true == m_bShowFlag) {
         activateWindow();
     }
